@charset "UTF-8";

html,
body {
	overflow-x: hidden;
}

@media (max-width: 960px) {
	.uk-section.uk-padding-large {
		padding-left: 0;
		padding-right: 0;
	}
}

.uk-button {
	font-family: "Archivo", sans-serif;
}

.in-button-app {
	background-color: #1a1a1a;
}

.in-button-app:hover {
	transition: all ease 200ms;
	background-color: #0d0c43;
}

@media (max-width: 960px) {
	.in-button-app {
		padding-left: 15px;
		padding-right: 15px;
	}
}

.in-highlight {
	position: relative;
	background: 0 0;
	z-index: 0;
	display: inline-block;
}

.in-highlight::before {
	content: "";
	background: #fcb420;
	border-radius: 5px;
	position: absolute;
	left: 0;
	right: -2px;
	bottom: -1px;
	height: 4px;
	z-index: -1;
}

.in-list-check > li {
	position: relative;
	padding-left: 30px;
}

.in-list-check > li::before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900;
	color: #3772ff;
	content: "\f058";
	position: absolute;
	top: 0;
	left: -12px;
	background-image: none;
}


header .uk-logo {
	margin-right: 55px;
}

header .in-optional-nav {
	width: auto;
}

header .in-optional-nav .uk-button-text {
	color: #fff;
	margin-right: 25px;
}


.uk-navbar-container {
	position: relative;
	z-index: 10;
	height: 92px;
}

.uk-navbar-nav {
	height: 92px;
}

.uk-navbar-nav a i {
	font-size: 7.5px;
	margin-top: 2px;
	margin-left: 3px;
	transition: all ease 200ms;
}

.uk-navbar-nav a[aria-expanded="true"] i {
	transition: all ease 200ms;
	transform: rotate(-180deg);
}

.uk-navbar-dropdown-nav a i {
	font-size: 13px;
}

.in-mobile-nav .uk-button {
	font-size: 17px;
	padding: 2px 16px;
	color: #fff;
	background-color: transparent;
	box-shadow: inset 0px 0px 0px 2px #e8e8e8;
	border-radius: 10px;
}

.uk-nav-default {
	margin-top: -40px;
}

.uk-nav-default li a {
	font-size: 24px;
}

.uk-nav-sub li a {
	font-size: 18px;
}

.uk-nav-sub li a i {
	margin-left: 8px;
	font-size: 13px;
}

@media (max-width: 960px) {
	.in-mobile-nav {
		position: absolute;
		right: 0;
		z-index: 2;
	}
}


.in-slideshow-gradient {
	background: #0d0c43;
	background: linear-gradient(0deg, #0a0936 0%, #0d0c43 80%, #0d0c43 100%);
	margin-top: -92px;
}

.in-slideshow {
	padding-top: 92px;
	height: 580px;
}

.in-slideshow.uk-background-contain {
	background-size: 1254px 710px;
	background-position: 84% -38px;
}

.in-slideshow .particles-js-canvas-el {
	position: relative;
	top: -810px;
}

.in-slideshow hr {
	position: relative;
	z-index: 1;
	border-top-color: rgba(255, 255, 255, 0.1);
}

.in-slideshow .uk-container {
	width: 100%;
	position: relative;
}

.in-slideshow .uk-slideshow-items {
	z-index: 1;
	height: 746px;
	top: -86px;
}

.in-slideshow .in-badge-text {
	height: 21px;
	color: #cacdd1;
	display: inline-block;
	background: rgba(255, 255, 255, 0.2);
	border-radius: 7px;
	padding: 7px 16px 6px;
}

.in-slideshow .in-badge-text .uk-label {
	color: #fff;
	background: #4886d9;
	margin: -2px 14px 0 -10px;
	padding-left: 12px;
	padding-right: 12px;
}

.in-slideshow .in-slide-text {
	margin-top: -59px;
}

.in-slideshow .in-slide-text .uk-text-lead {
	margin-top: 30px;
}

.in-slideshow .in-slide-img {
	position: absolute;
	right: 2px;
	-webkit-animation: float 6s ease-in-out infinite;
	animation: float 6s ease-in-out infinite;
}

.in-slideshow .uk-card-small {
	padding: 13px 12px 11px 16px;
}

.in-slideshow .uk-card-secondary {
	background: rgba(0, 0, 0, 0.2);
}

.in-slideshow .uk-card-secondary h6 {
	font-size: 11px;
}

.in-slideshow .uk-card-secondary h6 span.uk-text-small {
	color: #acacac;
	font-size: 11px;
	font-weight: 300;
	margin-left: 10px;
}

.in-slideshow .uk-card-secondary p {
	font-size: 15px;
	font-weight: 300;
}

.in-slideshow .uk-card-secondary p span.fa-arrow-circle-right,
.in-slideshow .uk-card-secondary p span.fa-spinner {
	font-size: 11px;
	margin: 5px 5px 0 0;
	float: left;
}

.in-slideshow .uk-card-secondary p span.fa-spinner::before {
	width: 11px;
	display: block;
	-webkit-animation: rotate 2s linear infinite;
	animation: rotate 2s linear infinite;
}

@-webkit-keyframes rotate {
	from {
		-webkit-transform: rotate(0deg);
	}

	to {
		-webkit-transform: rotate(360deg);
	}
}

@keyframes rotate {
	from {
		-webkit-transform: rotate(0deg);
	}

	to {
		-webkit-transform: rotate(360deg);
	}
}

.in-slideshow .in-symbol-logo img {
	margin: -3px 12px 0 0;
}

.in-slideshow .in-price.up p {
	color: #2db47f;
}

.in-slideshow .in-price.up p span.fa-arrow-circle-right {
	display: inline-block;
	transform: rotate(-40deg);
}

.in-slideshow .in-price.down p {
	color: #ec4e70;
}

.in-slideshow .in-price.down p span.fa-arrow-circle-right {
	display: inline-block;
	transform: rotate(40deg);
}

.in-slideshow .uk-dotnav {
	margin-bottom: 245px;
	z-index: 2;
}

.in-slideshow .uk-dotnav li {
	width: 22px;
	height: 22px;
	display: flex;
	align-items: center;
	justify-content: center;
}

@-webkit-keyframes float {
	0% {
		transform: translatey(0px);
	}

	50% {
		transform: translatey(-20px);
	}

	100% {
		transform: translatey(0px);
	}
}

@keyframes float {
	0% {
		transform: translatey(0px);
	}

	50% {
		transform: translatey(-20px);
	}

	100% {
		transform: translatey(0px);
	}
}

@media (max-width: 960px) {
	.in-slideshow-gradient {
		height: 700px;
	}

	.in-slideshow.uk-background-contain {
		background-size: 1100px 623px;
		background-position: -5% -38px;
	}

	.in-slideshow .particles-js-canvas-el {
		top: -691px;
	}

	.in-slideshow .uk-slideshow-items {
		height: 740px;
		top: -150px;
	}

	.in-slideshow .in-slide-text {
		text-align: center;
		margin-top: -160px;
	}

	.in-slideshow .in-slide-text h1 {
		font-size: 2.2rem;
	}

	.in-slideshow .in-slide-img {
		width: 80%;
		top: 92%;
		right: 10%;
	}

	.in-slideshow .uk-dotnav {
		margin-bottom: 80px;
		right: 8%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-slideshow-gradient {
		height: 532px;
	}

	.in-slideshow.uk-background-contain {
		background-position: -15% -38px;
	}

	.in-slideshow .particles-js-canvas-el {
		top: -601px;
	}

	.in-slideshow .uk-slideshow-items {
		height: 1330px;
		top: -580px;
	}

	.in-slideshow .in-slide-text {
		text-align: left;
		margin-top: 250px;
	}

	.in-slideshow .in-slide-img {
		width: 45%;
		right: 3%;
		top: 40%;
	}
}


footer .uk-link-text li a:hover {
	color: #e89903;
	text-decoration: none;
}

footer .in-footer-socials {
	text-align: right;
}

footer .in-footer-socials li {
	line-height: 36px;
}

footer .in-footer-socials li a {
	font-size: 12px;
	font-weight: 700;
	color: #fff;
	border-radius: 10px;
	padding: 8px 10px;
}

footer .in-footer-socials li a:hover {
	color: #fff;
	text-decoration: none;
}

footer .in-footer-socials li a .fab {
	font-size: 15px;
	color: #fff;
	margin-right: 8px;
	position: relative;
	top: 1px;
}

footer .in-footer-socials li a.fb-bg {
	background: #3b5998;
}

footer .in-footer-socials li a.fb-bg:hover {
	background: #466ab5;
}

footer .in-footer-socials li a.tw-bg {
	background: #00acee;
}

footer .in-footer-socials li a.tw-bg:hover {
	background: #18bfff;
}

footer .in-footer-socials li a.yt-bg {
	background: #c4302b;
}

footer .in-footer-socials li a.ld-bg {
	background: #0072b1;
}

footer .in-footer-socials li a.yt-bg:hover {
	background: #d64742;
}

footer .in-footer-socials li a.ig-bg {
	background: #dd2a7b;
}

footer .in-footer-socials li a.ig-bg:hover {
	background: #e34d91;
}

footer .in-footer-socials li a.tl-bg {
	background: #0088cc;
}

footer .in-footer-socials li a.tl-bg:hover {
	background: #00a3f5;
}

footer .in-footer-socials li a.wa-bg {
	background: #128c7e;
}

footer .in-footer-socials li a.wa-bg:hover {
	background: #17b09f;
}

footer .in-footer-socials li a.ld-bg {
	background: #0077b5;
}

footer .in-footer-socials li a.ld-bg:hover {
	background: #0092de;
}

footer .in-footer-socials li a.be-bg {
	background: #1769ff;
}

footer .in-footer-socials li a.be-bg:hover {
	background: #4083ff;
}

footer .uk-text-small {
	color: #212529;
}

@media (max-width: 960px) {
	footer .in-footer-socials {
		text-align: left;
		margin-top: 50px;
	}

	footer .in-footer-socials li {
		margin: 0 5px;
		display: inline-block;
	}

	footer .copyright-text {
		margin-top: 0;
	}
}



.in-blog-1 .in-stretch {
	width: 100%;
}

.in-blog-1 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-blog-1 .uk-card-body a {
	color: inherit;
	text-decoration: none;
}

.in-blog-1 .uk-card-body a.uk-button-text {
	color: #0d0c43;
}

.in-blog-1 .uk-card-body a.uk-button-text:hover {
	color: #f39f03;
}

.in-blog-1 .uk-card-media-top img {
	border-top-left-radius: 10px;
	border-top-right-radius: 10px;
}

.in-blog-1 .uk-card-footer {
	border-top: 1px solid #e8e8e8;
	padding-top: 17px;
}

.in-blog-1 .uk-card-footer .uk-button-text {
	margin-top: 0px;
}

@media (max-width: 960px) {
	.in-blog-1 .in-article-tags {
		width: 100%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-blog-1 .in-article-tags {
		width: initial;
	}
}

.in-blog-3 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-blog-3 .uk-card-default a {
	color: inherit;
	text-decoration: none;
}

.in-blog-3 .uk-card-default a.uk-button-text {
	color: #0d0c43;
}

.in-blog-3 .uk-card-default a.uk-button-text:hover {
	color: #f39f03;
}

.in-blog-3 .uk-card-default .uk-label {
	padding-left: 14px;
	padding-right: 14px;
}

.in-blog-4 a {
	color: inherit;
	text-decoration: none;
}

.in-blog-4 a.uk-button-text {
	color: #0d0c43;
}

.in-blog-4 a.uk-button-text:hover {
	color: #f39f03;
}

.in-blog-4 .uk-flex i {
	color: rgba(0, 0, 0, 0.28);
	top: 1px;
	position: relative;
}

.in-article .in-figure-available {
	margin-bottom: -158px;
}

.in-article blockquote {
	font-family: "Archivo", sans-serif;
	font-size: 22px;
	font-style: normal;
	border-left: 2px solid #e8e8e8;
	margin: 42px 0 42px 22px;
	padding-left: 45px;
}

.in-article blockquote p:first-of-type::before {
	content: "";
}

.in-article blockquote footer cite::before {
	content: "—";
	margin-right: 10px;
}

.in-article .in-article-tags {
	margin-top: 2px;
	font-size: 0.875rem;
}

.in-article .in-article-tags i {
	position: relative;
	top: 1px;
}

.in-article .in-article-share {
	margin-top: -2px;
}

.in-article .in-article-share a.uk-label {
	width: 16px;
	color: #fff;
	text-align: center;
}

.in-article .in-article-share a.uk-label:hover {
	text-decoration: none;
}

@media (max-width: 960px) {
	.in-article .in-figure-available {
		margin-bottom: 0;
	}

	.in-article .in-figure-available img.uk-width-1-1 {
		border-bottom-left-radius: 0;
		border-bottom-right-radius: 0;
		margin-bottom: -3px;
	}

	.in-article article.uk-card {
		z-index: -1;
	}

	.in-article blockquote {
		margin: 42px 0 42px 0px;
		padding-left: 30px;
	}
}

@media (max-width: 480px) {
	.in-article .in-article-share {
		margin: 10px 0 5px;
		float: left;
	}
}

.in-widget-tag .uk-label {
	font-size: 14px;
	background-color: #f5f7f9;
	border: 0;
	color: #707070;
	margin: 3px;
	padding: 4px 13px;
	transition: all ease 0.5s;
}

.in-widget-tag a:hover .uk-label {
	transition: all ease 0.5s;
	background-color: #fee8bf;
}

.in-widget-category li a,
.in-widget-latest li a {
	color: inherit;
}

.in-widget-category li a:hover,
.in-widget-latest li a:hover {
	color: #0e6ecd;
	text-decoration: none;
}


.in-card-3 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-3 img {
	border-top-right-radius: 5px;
	border-bottom-right-radius: 5px;
}

@media (max-width: 960px) {
	.in-card-3 img {
		border-top-left-radius: 5px;
		border-bottom-right-radius: 0;
	}
}

.in-card-4 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-8 .uk-card {
	border: 1px solid #e8e8e8;
	border-top: 3px solid #0d0c43;
	background-color: #fff;
	padding-top: 0px;
	padding-bottom: 0px;
}

.in-card-8 .uk-card .uk-grid > div {
	padding-top: 30px;
	padding-bottom: 30px;
}

.in-card-9 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-9 .uk-card-default .uk-tile {
	border: 1px solid #e8e8e8;
	border-right: 0;
	border-top: 0;
	padding: 25px 20px;
}

.in-card-9 .uk-card-default .uk-tile:first-child,
.in-card-9 .uk-card-default .uk-tile:nth-child(3) {
	border-left: 0;
}

.in-card-9 .uk-card-default .uk-tile:nth-child(n + 3) {
	border-bottom: 0;
}

.in-card-9 .uk-card-primary {
	border-top-right-radius: 5px;
	border-bottom-right-radius: 5px;
}

.in-card-9 .uk-card-primary .in-icon-wrap.small {
	width: 30px;
	height: 30px;
	background-color: rgba(255, 255, 255, 0.12);
}

.in-card-9 .uk-card-primary i {
	font-size: 12px;
	color: #fff;
}

.in-card-9 .uk-card-primary hr {
	margin: 25px 0 30px;
}

@media (max-width: 960px) {
	.in-card-9 .uk-card-default {
		border-bottom-right-radius: 0;
		border-bottom-left-radius: 0;
	}

	.in-card-9 .uk-card-default .uk-tile:nth-child(2) {
		border-left: 0;
	}

	.in-card-9 .uk-card-default .uk-tile:nth-child(n + 2) {
		border-bottom: 1px solid #e8e8e8;
	}

	.in-card-9 .uk-card-default .uk-tile:last-child {
		border-left: 0;
		border-bottom: 0;
	}

	.in-card-9 .uk-card-primary {
		border-top-right-radius: 0;
		border-bottom-left-radius: 5px;
	}
}

.in-card-10 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-10 .uk-card-default hr {
	border-width: 2px;
}

.in-card-10 .uk-card-default p {
	font-size: 0.882rem;
}

.in-card-10 .uk-card-default a {
	color: inherit;
	text-decoration: none;
}

.in-card-10 .uk-card-default a i {
	font-size: 11px;
	margin-top: 5px;
}

.in-card-10 .uk-card-body {
	padding: 28px;
}

.in-card-10 .uk-light .in-icon-wrap {
	background: rgba(255, 255, 255, 0.3);
	color: #fff;
}

.in-card-10 .in-card-green {
	background-color: #27bc9c;
}

.in-card-10 .in-card-blue {
	background-color: #4284dd;
}

.in-card-10 .in-card-purple {
	background-color: #9a5bb4;
}

.in-card-10 .in-card-navy {
	background-color: #35495d;
}

.in-card-10 .in-card-grey {
	background-color: #95a5a6;
}

.in-card-10 .in-card-orange {
	background-color: #fd6a4f;
}

.in-card-11 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-11 .uk-card-default .in-icon-wrap {
	background-color: rgba(30, 135, 240, 0.12);
}

.in-card-11 .uk-card-primary .in-icon-wrap,
.in-card-11 .uk-card-secondary .in-icon-wrap {
	background-color: rgba(255, 255, 255, 0.15);
	color: #fff;
}

.in-card-12 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-12 .uk-card-badge {
	position: absolute;
	top: -12px;
	right: -12px;
	padding-left: 12px;
	padding-right: 12px;
}

.in-card-12 .uk-position-bottom-right i {
	color: rgba(0, 0, 0, 0.08);
	position: relative;
	right: -20px;
}

.in-card-13 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-13 .uk-card-default img {
	border-top-left-radius: 5px;
	border-top-right-radius: 5px;
}

.in-card-13 .uk-card-default .uk-card-body {
	margin-top: -35px;
}

.in-card-13 .uk-card-default .in-icon-wrap {
	background-color: #0d0c43;
	color: #fff;
}

.in-card-14 .uk-card-default {
	background-color: transparent;
}

.in-card-14 .uk-card-default img {
	border-radius: 5px;
}

.in-card-14 .uk-card-default .in-icon-wrap.small {
	width: 24px;
	height: 24px;
	background-color: #0d0c43;
}

.in-card-14 .uk-card-default a {
	text-decoration: none;
}

.in-card-14 .uk-card-default i {
	top: -3px;
	font-size: 10px;
	color: #fff;
	position: relative;
}

.in-card-14 .uk-card-default .uk-card-body {
	width: 80%;
	margin: -30px auto 0;
	padding: 19px 18px 15px;
	border: 1px solid #e8e8e8;
	background-color: #fff;
	border-radius: 5px;
	position: relative;
	z-index: 3;
}

.in-card-16 .uk-card-default {
	border: 1px solid #0d0c43;
	background-color: #fff;
}

.in-card-18 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-card-18 .uk-card-default a {
	color: inherit;
	text-decoration: none;
}

.in-card-18 div:nth-child(2),
.in-card-18 div:nth-child(5) {
	position: relative;
	top: 30px;
}

@media (max-width: 960px) {
	.in-card-18 div:nth-child(2),
	.in-card-18 div:nth-child(5) {
		top: 0px;
	}
}

.in-card-paper {
	position: relative;
	background-color: #fff;
	box-shadow: 0 0 10px rgba(0, 0, 0, 0.2);
	border-radius: 0;
	border-color: rgba(0, 0, 0, 0.1);
}

.in-card-paper:before,
.in-card-paper:after {
	box-shadow: 1px 1px 2px #ddd;
	border: 1px solid rgba(0, 0, 0, 0.1);
	background-color: inherit;
	position: absolute;
	content: "";
	right: 0;
	left: 0;
	bottom: 0;
	top: 0;
}

.in-card-paper:before {
	transform: rotate(1deg);
	z-index: -1;
	top: -1px;
}

.in-card-paper:after {
	transform: rotate(-1deg);
	z-index: -2;
	left: -1px;
}

.in-card-paper .uk-card-small {
	padding: 18px 22px;
}


.in-client-logo-1 .uk-tile {
	background: #f5f7f9;
	border: 1px solid #e8e8e8;
	border-right: 0;
	border-top: 0;
	padding: 28px 0;
}

.in-client-logo-1 .uk-tile:first-child,
.in-client-logo-1 .uk-tile:nth-child(6) {
	border-left: 0;
}

.in-client-logo-1 .uk-tile:nth-child(n + 6) {
	border-bottom: 0;
}

.in-client-logo-1 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-1 .uk-tile img:hover {
	opacity: 1;
}

@media (max-width: 960px) {
	.in-client-logo-1 {
		padding: 0;
	}

	.in-client-logo-1 .uk-tile {
		border-left: 0;
		border-right: 0;
	}

	.in-client-logo-1 .uk-tile:nth-child(n + 6) {
		border-bottom: 1px solid #e8e8e8;
	}

	.in-client-logo-1 .uk-tile:last-child {
		border-bottom: 0;
	}
}

.in-client-logo-2 .uk-tile {
	background: #f5f7f9;
	border: 1px solid #e8e8e8;
}

.in-client-logo-2 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-2 .uk-tile img:hover {
	opacity: 1;
}

.in-client-logo-3 .uk-tile {
	background: #f5f7f9;
	padding: 10px 25px;
}

.in-client-logo-3 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-3 .uk-tile img:hover {
	opacity: 1;
}

.in-client-logo-4 {
	padding: 0 80px;
}

.in-client-logo-4 .uk-tile {
	background: #f5f7f9;
	padding: 10px 35px;
}

.in-client-logo-4 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-4 .uk-tile img:hover {
	opacity: 1;
}

@media (max-width: 960px) {
	.in-client-logo-4 {
		padding: 0;
	}
}

.in-client-logo-5 .uk-tile {
	background: #f5f7f9;
	border: 1px solid #e8e8e8;
	border-right: 0;
	border-top: 0;
	padding: 50px;
}

.in-client-logo-5 .uk-tile:first-child,
.in-client-logo-5 .uk-tile:nth-child(4) {
	border-left: 0;
}

.in-client-logo-5 .uk-tile:nth-child(n + 4) {
	border-bottom: 0;
}

.in-client-logo-5 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-5 .uk-tile img:hover {
	opacity: 1;
}

@media (max-width: 960px) {
	.in-client-logo-5 .uk-tile {
		padding: 28px 0;
		border-left: 0;
		border-right: 0;
	}

	.in-client-logo-5 .uk-tile:nth-child(n + 4) {
		border-bottom: 1px solid #e8e8e8;
	}

	.in-client-logo-5 .uk-tile:last-child {
		border-bottom: 0;
	}
}

.in-client-logo-6 .uk-tile {
	background: #f5f7f9;
	border-right: 1px solid #e8e8e8;
	padding: 10px 35px;
}

.in-client-logo-6 .uk-tile:last-child {
	border-right: 0;
}

.in-client-logo-6 .uk-tile img {
	opacity: 0.8;
	transition: 0.3s ease-in-out;
}

.in-client-logo-6 .uk-tile img:hover {
	opacity: 1;
}

@media (max-width: 960px) {
	.in-client-logo-6 .uk-tile {
		padding: 28px 0;
		border-right: 0;
		border-bottom: 1px solid #e8e8e8;
	}

	.in-client-logo-6 .uk-tile:last-child {
		border-bottom: 0;
	}
}


@media (max-width: 960px) {
	.in-contact-1 iframe {
		height: 300px;
	}
}

.in-contact-6 .uk-text-small.uk-text-muted {
	margin-top: 5px;
}

@media (max-width: 960px) {
	.in-contact-6 iframe {
		height: 300px;
	}
}


.in-content-3 .in-office-location {
	color: #4886d9;
}

.in-content-10 .uk-card-primary h1 {
	color: #333333;
}

.in-content-10 .in-icon-wrap {
	color: #dbdbdb;
}

.in-content-10
	.uk-card-primary.uk-card-body
	.uk-search-default
	.uk-search-input {
	height: 46px;
	background-color: #fff;
	box-shadow: 0 1px 6px rgba(0, 0, 0, 0.08);
	padding-left: 50px;
}

.in-content-10 .uk-card-primary.uk-card-body .uk-search .uk-search-icon {
	padding-left: 8px;
}

.in-content-10 .uk-card-primary.uk-card-body .uk-search .uk-search-icon,
.in-content-10 .uk-card-primary.uk-card-body .uk-search .uk-search-icon:hover,
.in-content-10 .uk-card-primary.uk-card-body .uk-search-input {
	color: #666;
}

.in-content-10 .uk-card-primary.uk-card-body .uk-search-input::placeholder {
	color: #212529;
}

@media (max-width: 960px) {
	.in-content-10 .uk-card.uk-background-contain {
		background-size: 600px 134px;
	}

	.in-content-10 .uk-card.uk-background-center {
		background-position: -10% 0% !important;
	}
}

.in-content-11 .uk-card-default {
	transition: all ease 0.5s;
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-content-11 .uk-card-default h4 {
	color: #333333;
}

.in-content-11 .uk-card-default .in-icon-wrap {
	background-color: #333333;
	color: #fff;
	transition: all ease 0.5s;
}

.in-content-11 .uk-card-default .uk-text-small {
	color: #666;
}

.in-content-11 .uk-card-default:hover {
	border-color: #0d0c43;
	text-decoration: none;
}

.in-content-11 .uk-card-default:hover .in-icon-wrap {
	background-color: #0d0c43;
	transition: all ease 0.5s;
}


.in-counter-1 .uk-card-default {
	background-color: #fff;
}

.in-counter-1 .uk-card-body {
	padding: 28px;
}

.in-counter-2 .uk-divider-small::after {
	border-color: #0d0c43;
}

.in-counter-4 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-counter-6 .uk-card-default {
	border: 2px solid #e8e8e8;
	border-radius: 10px;
	background-color: #fff;
}


.in-faq-1 .uk-accordion-title {
	padding: 20px 12px;
	border-bottom: 1px solid #e8e8e8;
}

.in-faq-1 .uk-accordion-title::before {
	content: "\f055";
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	font-size: 14px;
	color: #0d0c43;
	margin: 5px 12px 5px 0;
	float: left;
}

.in-faq-1 .uk-open .uk-accordion-title {
	color: #0d0c43;
	border-bottom: 0;
}

.in-faq-1 .uk-open .uk-accordion-title::before {
	content: "\f056";
}

.in-faq-1 .uk-accordion-content {
	border-bottom: 1px solid #e8e8e8;
	margin-top: 0px;
	padding: 0 38px 30px;
}

.in-faq-1 li:last-child .uk-accordion-title,
.in-faq-1 li:last-child .uk-accordion-content {
	border-bottom: 0;
}

.in-faq-2 {
	margin-top: -20px;
}

.in-faq-2 .uk-accordion-title {
	margin-top: 20px;
}

.in-faq-2 .uk-accordion-title .uk-card-default::after {
	content: "\f105";
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	font-size: 14px;
	top: 25px;
	right: 22px;
	position: absolute;
}

.in-faq-2 .uk-accordion-title .uk-card-body {
	padding: 20px 22px;
}

.in-faq-2 .uk-accordion-title i {
	margin: 6px 12px 7px 0;
	float: left;
}

.in-faq-2 .uk-accordion-title[aria-expanded="true"] .uk-card {
	background-color: #0d0c43;
	color: #fff;
	border-bottom-left-radius: 0px;
	border-bottom-right-radius: 0px;
}

.in-faq-2 .uk-accordion-title[aria-expanded="true"] .uk-card::after {
	content: "\f107";
}

.in-faq-2 .uk-accordion-content {
	margin-top: 0px;
}

.in-faq-2 .uk-accordion-content.uk-card-default {
	border-top-left-radius: 0px;
	border-top-right-radius: 0px;
}

.in-faq-3 {
	margin-top: -20px;
}

.in-faq-3 .uk-card-default {
	margin-top: 20px;
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-faq-3 .uk-card-body {
	padding: 20px 22px;
}

.in-faq-3 .uk-accordion-title::after {
	content: "\f0da";
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	font-size: 14px;
	top: 25px;
	right: 22px;
	position: absolute;
}

.in-faq-3 .uk-open .uk-accordion-title::after {
	content: "\f0d7";
}

.in-faq-3 .uk-open .uk-accordion-title {
	color: #0d0c43;
}

.in-faq-3 .uk-accordion-content {
	padding: 0px 14px 8px 0px;
}

.in-faq-4 {
	margin-top: -20px;
}

.in-faq-4 .uk-card-default {
	margin-top: 20px;
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-faq-4 .uk-card-body {
	padding: 20px 22px;
}

.in-faq-4 .uk-accordion-title::after {
	content: "\f067";
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	font-size: 14px;
	top: 25px;
	right: 22px;
	position: absolute;
}

.in-faq-4 .uk-open .uk-accordion-title::after {
	content: "\f068";
}

.in-faq-4 .uk-open .uk-accordion-title {
	color: #0d0c43;
}

.in-faq-4 .uk-accordion-content {
	padding: 0px 14px 8px 0px;
}

.in-faq-5 .uk-accordion-title {
	padding: 15px 0;
}

.in-faq-5 .uk-accordion-title::before {
	content: "\f053";
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	font-size: 13px;
	color: inherit;
	margin: 5px 0;
	float: right;
}

.in-faq-5 .uk-open .uk-accordion-title {
	color: #0d0c43;
	border-bottom: 0;
}

.in-faq-5 .uk-open .uk-accordion-title::before {
	content: "\f078";
}

.in-faq-5 .uk-accordion-content {
	margin-top: 0px;
	padding-bottom: 10px;
}

.in-faq-5 li:last-child .uk-accordion-title,
.in-faq-5 li:last-child .uk-accordion-content {
	border-bottom: 0;
}


.in-gallery-2 .uk-overlay {
	padding: 22px 22px 68px 68px;
}

.in-gallery-2 .uk-overlay-primary {
	background: black;
	background: radial-gradient(
		circle farthest-corner at top right,
		rgba(0, 0, 0, 0.48) 0%,
		rgba(0, 0, 0, 0.12) 50%,
		rgba(255, 255, 255, 0) 65%
	);
}

.in-gallery-2 .uk-inline-clip {
	background-color: #000;
}

.in-gallery-2 .uk-inline-clip a img {
	transition: all ease 300ms;
}

.in-gallery-2 .uk-inline-clip a:hover img {
	transition: all ease 300ms;
	opacity: 0.8;
}

.in-gallery-2 .fas {
	font-size: 20px;
}

.in-gallery-3 .uk-overlay {
	padding-bottom: 100px;
}

.in-gallery-3 .uk-overlay-primary {
	background: #000000;
	background: linear-gradient(
		to bottom,
		rgba(0, 0, 0, 0.52) 0%,
		rgba(255, 255, 255, 0) 100%
	);
}

.in-gallery-3 .uk-overlay-primary .uk-text-muted {
	color: rgba(255, 255, 255, 0.7) !important;
}

.in-gallery-3 .uk-inline-clip {
	background-color: #fff;
}

.in-gallery-3 .uk-inline-clip a img {
	transition: all ease 300ms;
}

.in-gallery-3 .uk-inline-clip a:hover img {
	filter: blur(2px);
	-webkit-filter: blur(2px);
	transition: all ease 300ms;
	opacity: 0.8;
}

.in-gallery-3 .uk-button-default {
	padding-top: 6px;
	padding-bottom: 6px;
}

.in-gallery-3 .uk-dropdown {
	background-color: #fff;
	border-bottom-left-radius: 5px;
	border-bottom-right-radius: 5px;
	border: 1px solid #ccc;
	border-top-color: #fff;
	font-size: 16px;
	min-width: 177px;
	padding: 5px 28px 10px;
}


.in-pricing-1 .uk-card {
	overflow: hidden;
	border-radius: 10px;
	border: 2px solid #e8e8e8;
	transition: all ease 600ms;
}

.in-pricing-1 .uk-card-default {
	background-color: #fff;
}

.in-pricing-1 .uk-card-default:hover {
	border-color: #d1d1d1;
}

.in-pricing-1 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -15px;
	top: -3px;
	position: relative;
}

.in-pricing-1 .uk-card-header hr {
	margin-top: 40px;
	margin-bottom: -25px;
}

.in-pricing-1 .uk-card-header .uk-label {
	background-color: #252526;
}

.in-pricing-1 .uk-card-header .uk-card-badge {
	margin: 10px 8px 0 0;
}

.in-pricing-1 .uk-card-header i {
	color: rgba(0, 0, 0, 0.1);
}

.in-pricing-1 .uk-card-body .uk-list-bullet > li::before {
	background-image: none;
	font-size: 14px;
	font-family: "Font Awesome 5 Free";
	font-weight: 900;
	content: "\f00c";
	color: #0d0c43;
	top: 1px;
	left: 4px;
}

.in-pricing-1.in-pricing-featured .uk-card {
	border-color: #0d0c43;
}

.in-pricing-1.in-pricing-featured .uk-card:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-1.in-pricing-featured .uk-card-header .uk-label {
	background-color: #0d0c43;
}

.in-pricing-2 .uk-card {
	transition: all ease 600ms;
}

.in-pricing-2 .uk-card-default {
	background-color: #fff;
	border-bottom-left-radius: 10px;
	border-bottom-right-radius: 10px;
}

.in-pricing-2 .uk-card-header {
	border-top-left-radius: 10px;
	border-top-right-radius: 10px;
	border-top: 0;
	background-color: #252526;
}

.in-pricing-2 .uk-card-header h3 {
	color: #fff;
}

.in-pricing-2 .uk-card-header h4 {
	color: #fff;
}

.in-pricing-2 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -10px;
	top: -3px;
	position: relative;
}

.in-pricing-2 .uk-card-body {
	padding-top: 25px;
	box-shadow: inset 0px 0px 0px 1px #e8e8e8;
	border-bottom-left-radius: 10px;
	border-bottom-right-radius: 10px;
	transition: all ease 600ms;
}

.in-pricing-2.in-pricing-featured .uk-card:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-2.in-pricing-featured .uk-card-header {
	background-color: #0d0c43;
}

.in-pricing-3 .uk-card {
	overflow: hidden;
	border-radius: 5px;
	border: 1px solid #e8e8e8;
	border-top: 0;
	transition: all ease 600ms;
}

.in-pricing-3 .uk-card-default {
	background-color: #fff;
}

.in-pricing-3 .uk-card-default:hover {
	border-color: #d1d1d1;
}

.in-pricing-3 .uk-card-header {
	border-top: 4px solid #252526;
	border-radius: 5px;
}

.in-pricing-3 .uk-card-header h6 {
	letter-spacing: 2px;
}

.in-pricing-3 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -15px;
	top: -26px;
	position: relative;
}

.in-pricing-3 .uk-card-header .uk-label {
	background: transparent;
	color: #252526;
}

.in-pricing-3.in-pricing-featured .uk-card {
	border-color: #0d0c43;
}

.in-pricing-3.in-pricing-featured .uk-card:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-3.in-pricing-featured .uk-card-header {
	border-color: #0d0c43;
}

.in-pricing-3.in-pricing-featured
	.uk-card-body
	.uk-list-divider
	> li:nth-child(n + 2) {
	border-color: #fdcf78;
}

.in-pricing-4 .uk-card {
	overflow: hidden;
	border-radius: 10px;
	border: 1px solid #e8e8e8;
	transition: all ease 600ms;
}

.in-pricing-4 .uk-card-default {
	background-color: #fff;
}

.in-pricing-4 .uk-card-default:hover {
	border-color: #d1d1d1;
}

.in-pricing-4 .uk-card-header h6 {
	letter-spacing: 2px;
}

.in-pricing-4 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -15px;
	top: -18px;
	position: relative;
}

.in-pricing-4 .uk-card-body {
	padding-top: 15px;
}

.in-pricing-4 .uk-card-body .uk-list-bullet > li::before {
	background-image: none;
	font-size: 14px;
	font-family: "Font Awesome 5 Free";
	font-weight: 900;
	content: "\f00c";
	color: #0d0c43;
	top: 1px;
	left: 4px;
}

.in-pricing-4.in-pricing-featured .uk-card {
	border-color: #0d0c43;
}

.in-pricing-4.in-pricing-featured .uk-card:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-4.in-pricing-featured .uk-card-header {
	border-color: #0d0c43;
}

.in-pricing-4.in-pricing-featured .uk-card-header .in-icon-wrap {
	background-color: #0d0c43;
	color: #fff;
}

.in-pricing-5 .uk-card {
	overflow: hidden;
	border-radius: 10px;
	border: 2px solid #e8e8e8;
	transition: all ease 600ms;
}

.in-pricing-5 .uk-card-default {
	background-color: #fff;
}

.in-pricing-5 .uk-card-default:hover {
	border-color: #d1d1d1;
}

.in-pricing-5 .uk-card-header h6 {
	color: #fff;
}

.in-pricing-5 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -15px;
	top: -3px;
	position: relative;
}

.in-pricing-5 .uk-card-header .in-pricing-month {
	font-size: 24px;
	margin-left: -10px;
}

.in-pricing-5 .uk-card-header hr {
	width: 60%;
	margin: 35px auto -20px;
}

.in-pricing-5 .uk-card-header .uk-card-badge {
	top: -26px;
	left: 0%;
	position: relative;
}

.in-pricing-5 .uk-card-header .uk-label {
	padding: 14px 25px 9px;
	border-bottom-left-radius: 5px;
	border-bottom-right-radius: 5px;
	background-color: #252526;
}

.in-pricing-5.in-pricing-featured .uk-card {
	border-color: #0d0c43;
}

.in-pricing-5.in-pricing-featured .uk-card:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-5.in-pricing-featured .uk-card-header .uk-label {
	background-color: #0d0c43;
}

.in-pricing-6 .uk-card {
	transition: all ease 600ms;
}

.in-pricing-6 .uk-card-default {
	background-color: rgba(0, 0, 0, 0.02);
	border-bottom-left-radius: 5px;
	border-bottom-right-radius: 5px;
}

.in-pricing-6 .uk-card-header {
	box-shadow: inset 0px 0px 0px 1px #e8e8e8;
	border-top: 4px solid #252526;
	border-top-left-radius: 5px;
	border-top-right-radius: 5px;
	background-color: #fff;
	margin-bottom: -1px;
	padding-top: 30px;
	padding-bottom: 35px;
}

.in-pricing-6 .uk-card-header h3 {
	margin: 12px 0 -20px;
}

.in-pricing-6 .uk-card-header .in-pricing-small {
	font-size: 24px;
	margin-right: -10px;
	top: -17px;
	position: relative;
}

.in-pricing-6 .uk-card-header .uk-label {
	background-color: #252526;
}

.in-pricing-6 .uk-card-body {
	padding-top: 35px;
	box-shadow: inset 0px 0px 0px 1px #e8e8e8;
	border-bottom-left-radius: 5px;
	border-bottom-right-radius: 5px;
	transition: all ease 600ms;
}

.in-pricing-6 .uk-card-body .uk-list-bullet > li::before {
	background-image: none;
	font-size: 14px;
	font-family: "Font Awesome 5 Free";
	font-weight: 900;
	content: "\f00c";
	color: #0d0c43;
	top: 1px;
	left: 4px;
}

.in-pricing-6.in-pricing-featured .uk-card-default:hover {
	background-color: white;
	border-color: #0d0c43;
}

.in-pricing-6.in-pricing-featured .uk-card-header {
	border-color: #0d0c43;
}

.in-pricing-6.in-pricing-featured .uk-card-header .uk-label {
	background-color: #0d0c43;
}


.in-team-3 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
	padding-top: 30px;
	padding-bottom: 30px;
}


.in-testimonial-2 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-testimonial-6 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-testimonial-6 .fa-star {
	color: #f6c416;
	font-size: 12px;
	position: relative;
	top: 16px;
}

@media (max-width: 960px) {
	.in-testimonial-6 .uk-float-right {
		margin-bottom: -22px;
	}

	.in-testimonial-6 .fa-star {
		top: -26px;
		left: 64px;
	}
}

.in-testimonial-7 .uk-card {
	padding-top: 20px;
	padding-bottom: 20px;
}

.in-testimonial-7 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-testimonial-8 .uk-card {
	padding-top: 20px;
	padding-bottom: 15px;
}

.in-testimonial-8 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

@media (max-width: 960px) {
	.in-testimonial-8 .uk-position-bottom-right {
		width: 46%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-testimonial-8 .uk-position-bottom-right {
		width: 26%;
	}
}


.in-timeline-1 hr {
	margin-bottom: 0;
}

.in-timeline-1 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-timeline-1 .uk-label {
	position: relative;
	top: -1px;
	left: 10px;
}

.in-timeline-1 .in-timeline-branch .in-icon-wrap {
	font-weight: 700;
	position: relative;
	top: 21px;
	left: 38px;
}

.in-timeline-1 .in-timeline-branch .in-timeline-title {
	height: 105px;
	border-left: 1px solid #e8e8e8;
	margin-left: 5px;
	padding-left: 40px;
}

@media (max-width: 960px) {
	.in-timeline-1 > .uk-child-width-1-1 > div {
		margin-top: 0;
	}
}

.in-timeline-2 {
	margin: 30px auto;
	position: relative;
	padding: 1px 10px;
}

.in-timeline-2 .uk-card-default {
	border: 1px solid #e8e8e8;
	background-color: #fff;
}

.in-timeline-2:before {
	content: "";
	width: 3px;
	height: 100%;
	background: #e8e8e8;
	left: 50%;
	top: 0;
	position: absolute;
}

.in-timeline-2:after {
	content: "";
	clear: both;
	display: table;
	width: 100%;
}

.in-timeline-2 .in-timeline-item {
	margin: 25px 0;
	position: relative;
}

.in-timeline-2 .in-timeline-item:after,
.in-timeline-2 .in-timeline-item:before {
	content: "";
	display: block;
	width: 100%;
	clear: both;
}

.in-timeline-2 .in-timeline-item:before {
	width: 13px;
	height: 13px;
	background: #0d0c43;
	border: 10px solid #fff;
	border-radius: 50%;
	position: absolute;
	top: 20px;
	left: 50%;
	overflow: hidden;
	margin-left: -15px;
}

.in-timeline-2 .in-timeline-item .in-timeline-content {
	width: 45%;
}

.in-timeline-2 .in-timeline-item .in-timeline-content.right {
	float: right;
}

.in-timeline-2 .in-timeline-item .in-timeline-content.uk-card-body {
	padding-bottom: 25px;
}

.in-timeline-2
	.in-timeline-item
	.in-timeline-content
	.uk-position-bottom-right
	i {
	color: rgba(0, 0, 0, 0.08);
	position: relative;
	right: -20px;
}

@media (max-width: 960px) {
	.in-timeline-2 {
		margin: 10px 0;
		padding: 1px 0;
		width: 100%;
	}

	.in-timeline-2:before {
		left: 0;
	}

	.in-timeline-2 .in-timeline-item:before {
		left: 0;
	}

	.in-timeline-2 .in-timeline-item .in-timeline-content {
		width: 93%;
		float: right;
	}
}

@media (max-width: 640px) {
	.in-timeline-2 .in-timeline-item .in-timeline-content {
		width: 90%;
	}
}


@-webkit-keyframes hideLoader {
	0% {
		width: 100%;
		height: 100%;
	}

	100% {
		width: 0;
		height: 0;
	}
}
@keyframes hideLoader {
	0% {
		width: 100%;
		height: 100%;
	}

	100% {
		width: 0;
		height: 0;
	}
}

body > div.in-loader {
	position: fixed;
	background: white;
	width: 100%;
	height: 100%;
	z-index: 1000;
	opacity: 0;
	transition: opacity 0.5s ease;
	overflow: hidden;
	pointer-events: none;
	display: flex;
	align-items: center;
	justify-content: center;
}

body > div.in-loader div {
	width: 1rem;
	height: 1rem;
	margin: 2rem 0.3rem;
	background: #3772ff;
	border-radius: 50%;
	-webkit-animation: 0.9s bounce infinite alternate;
	animation: 0.9s bounce infinite alternate;
}

body > div.in-loader div:nth-child(2) {
	-webkit-animation-delay: 0.3s;
	animation-delay: 0.3s;
}

body > div.in-loader div:nth-child(3) {
	-webkit-animation-delay: 0.6s;
	animation-delay: 0.6s;
}

body:not(.loaded) > div.in-loader {
	opacity: 1;
}

body:not(.loaded) {
	overflow: hidden;
}

body.loaded > div.in-loader {
	-webkit-animation: hideLoader 0.5s linear 0.5s forwards;
	animation: hideLoader 0.5s linear 0.5s forwards;
}

@-webkit-keyframes bounce {
	to {
		opacity: 0.3;
		transform: translate3d(0, -1rem, 0);
	}
}

@keyframes bounce {
	to {
		opacity: 0.3;
		transform: translate3d(0, -1rem, 0);
	}
}

.in-brand-google,
a.in-brand-google {
	background-color: #4687f2;
	color: #fff;
}

.in-brand-google:hover,
a.in-brand-google:hover {
	background-color: #639af4;
}

.in-brand-facebook,
a.in-brand-facebook {
	background-color: #3b5999;
	color: #fff;
}

.in-brand-facebook:hover,
a.in-brand-facebook:hover {
	background-color: #4d70ba;
}

.in-brand-twitter,
a.in-brand-twitter {
	background-color: #1da1f2;
	color: #fff;
}

.in-brand-twitter:hover,
a.in-brand-twitter:hover {
	background-color: #3aadf4;
}

.in-brand-pinterest,
a.in-brand-pinterest {
	background-color: #bd081c;
	color: #fff;
}

.in-brand-pinterest:hover,
a.in-brand-pinterest:hover {
	background-color: #da0920;
}

.in-brand-youtube,
a.in-brand-youtube {
	background-color: #cd201f;
	color: #fff;
}

.in-brand-youtube:hover,
a.in-brand-youtube:hover {
	background-color: #df2d2c;
}

.in-generic-email,
a.in-generic-email {
	background-color: #37474f;
	color: #fff;
}

.in-generic-email:hover,
a.in-generic-email:hover {
	background-color: #445761;
}


.in-button-app {
	font-weight: 300;
	font-size: 13px;
	text-transform: capitalize;
	text-align: left;
	line-height: 17px;
	padding: 12px 23px 13px;
}

.in-button-app span.wrapper {
	float: right;
}

.in-button-app span.wrapper span {
	font-weight: 700;
	font-size: 15px;
}

.in-button-app span.wrapper span::before {
	content: "\A";
	white-space: pre;
}

.in-button-app i {
	margin-right: 14px;
	position: relative;
	top: 4px;
}

@font-face {
	font-family: "Archivo";
	font-style: normal;
	font-weight: 400;
	src: local(""),
		url("../fonts/archivo-v9-latin-regular.woff2") format("woff2"),
		url("../fonts/archivo-v9-latin-regular.woff") format("woff");
	font-display: swap;
}

@font-face {
	font-family: "Archivo";
	font-style: normal;
	font-weight: 300;
	src: local(""), url("../fonts/archivo-v9-latin-300.woff2") format("woff2"),
		url("../fonts/archivo-v9-latin-300.woff") format("woff");
	font-display: swap;
}

@font-face {
	font-family: "Archivo";
	font-style: normal;
	font-weight: 700;
	src: local(""), url("../fonts/archivo-v9-latin-700.woff2") format("woff2"),
		url("../fonts/archivo-v9-latin-700.woff") format("woff");
	font-display: swap;
}

.in-icon-wrap {
	font-family: inherit;
	font-weight: inherit;
	display: inline-flex;
	justify-content: center;
	align-items: center;
	width: 64px;
	height: 64px;
	background-color: #f0f0f0;
	color: #5c5c5c;
	border-radius: 24px;
}

.in-icon-wrap.small {
	width: 38px;
	height: 38px;
	border-radius: 14px;
}

.in-icon-wrap.large {
	width: 92px;
	height: 92px;
	border-radius: 34px;
}

.in-icon-wrap.circle {
	border-radius: 500px;
}

.in-icon-wrap.transparent {
	background-color: transparent;
}

.in-icon-wrap.primary-color {
	background-color: #0d0c43;
	color: #fff;
}

.in-icon-wrap.secondary-color {
	background-color: #5c5c5c;
	color: #fff;
}


.in-offset-top-10 {
	margin-top: -10px;
}

.in-offset-top-20 {
	margin-top: -20px;
}

.in-offset-top-30 {
	margin-top: -30px;
}

.in-offset-top-40 {
	margin-top: -40px;
}

.in-offset-top-50 {
	margin-top: -50px;
}

.in-offset-top-60 {
	margin-top: -60px;
}

.in-offset-top-70 {
	margin-top: -70px;
}

.in-offset-top-80 {
	margin-top: -80px;
}


.in-offset-bottom-10 {
	margin-bottom: -10px;
}

.in-offset-bottom-20 {
	margin-bottom: -20px;
}

.in-offset-bottom-30 {
	margin-bottom: -30px;
}

.in-offset-bottom-40 {
	margin-bottom: -40px;
}

.in-offset-bottom-50 {
	margin-bottom: -50px;
}

.in-offset-bottom-60 {
	margin-bottom: -60px;
}

.in-offset-bottom-70 {
	margin-bottom: -70px;
}

.in-offset-bottom-80 {
	margin-bottom: -80px;
}

@media (max-width: 960px) {
	
	.in-offset-top-10\@s {
		margin-top: -10px;
	}

	.in-offset-top-20\@s {
		margin-top: -20px;
	}

	.in-offset-top-30\@s {
		margin-top: -30px;
	}

	.in-offset-top-40\@s {
		margin-top: -40px;
	}

	.in-offset-top-50\@s {
		margin-top: -50px;
	}

	.in-offset-top-60\@s {
		margin-top: -60px;
	}

	.in-offset-top-70\@s {
		margin-top: -70px;
	}

	.in-offset-top-80\@s {
		margin-top: -80px;
	}

	
	.in-offset-bottom-10\@s {
		margin-bottom: -10px;
	}

	.in-offset-bottom-20\@s {
		margin-bottom: -20px;
	}

	.in-offset-bottom-30\@s {
		margin-bottom: -30px;
	}

	.in-offset-bottom-40\@s {
		margin-bottom: -40px;
	}

	.in-offset-bottom-50\@s {
		margin-bottom: -50px;
	}

	.in-offset-bottom-60\@s {
		margin-bottom: -60px;
	}

	.in-offset-bottom-70\@s {
		margin-bottom: -70px;
	}

	.in-offset-bottom-80\@s {
		margin-bottom: -80px;
	}

	
	.in-margin-remove-top\@s {
		margin-top: 0 !important;
	}

	.in-margin-remove-left\@s {
		margin-left: 0 !important;
	}

	.in-margin-remove-right\@s {
		margin-right: 0 !important;
	}

	.in-margin-remove-bottom\@s {
		margin-bottom: 0 !important;
	}

	
	.in-margin-top-10\@s {
		margin-top: 10px !important;
	}

	.in-margin-top-20\@s {
		margin-top: 20px !important;
	}

	.in-margin-top-30\@s {
		margin-top: 30px !important;
	}

	.in-margin-top-40\@s {
		margin-top: 40px !important;
	}

	.in-margin-top-50\@s {
		margin-top: 50px !important;
	}

	.in-margin-top-60\@s {
		margin-top: 60px !important;
	}

	.in-margin-top-70\@s {
		margin-top: 70px !important;
	}

	.in-margin-top-80\@s {
		margin-top: 80px !important;
	}

	.in-margin-bottom-10\@s {
		margin-bottom: 10px !important;
	}

	.in-margin-bottom-20\@s {
		margin-bottom: 20px !important;
	}

	.in-margin-bottom-30\@s {
		margin-bottom: 30px !important;
	}

	.in-margin-bottom-40\@s {
		margin-bottom: 40px !important;
	}

	.in-margin-bottom-50\@s {
		margin-bottom: 50px !important;
	}

	.in-margin-bottom-60\@s {
		margin-bottom: 60px !important;
	}

	.in-margin-bottom-70\@s {
		margin-bottom: 70px !important;
	}

	.in-margin-bottom-80\@s {
		margin-bottom: 80px !important;
	}

	
	.in-padding-horizontal\@s {
		padding: 0 30px;
	}

	.in-padding-large-horizontal\@s {
		padding: 0 60px;
	}

	.in-padding-vertical\@s {
		padding: 30px 0;
	}

	.in-padding-large-vertical\@s {
		padding: 60px 0;
	}
}

.in-totop {
	font-size: 15px;
	display: inline-flex;
	justify-content: center;
	align-items: center;
	width: 45px;
	height: 45px;
	position: fixed;
	right: 40px;
	bottom: 40px;
	background-color: #0d0c43;
	border-radius: 10px;
	opacity: 0;
}

.in-totop.left {
    left: 40px;
    right: auto;
}

.in-totop.uk-animation-slide-top {
	opacity: 1;
}

a.in-totop {
	color: #fff;
	text-decoration: none;
}

.in-z-index {
	position: relative;
}

.in-z-index.top {
	z-index: 1;
}

.in-z-index.bottom {
	z-index: -1;
}


.in-video-wrapper .plyr,
.in-audio-wrapper .plyr {
	border-radius: 5px;
}

#disqus_thread {
	overflow: hidden;
}

#disqus_thread::before {
	content: "";
	display: block;
	height: 2px;
	width: 106px;
	bottom: -41px;
	position: relative;
	background: #0d0c43;
}

#disqus_thread iframe {
	margin-bottom: -54px;
}

@-moz-document url-prefix() {
	#disqus_thread::before {
		width: 103px;
	}
}

.in-disqus-util {
	margin-top: -59px;
}

.in-disqus-util .hide-privacy-policy {
	content: "";
	display: block;
	height: 39px;
	width: 298px;
	left: 104px;
	bottom: -59px;
	position: relative;
	background: #f5f7f9;
}

.in-disqus-util .hide-share-button {
	content: "";
	display: block;
	height: 20px;
	width: 290px;
	bottom: -74px;
	position: relative;
	background: #f5f7f9;
}

@media (max-width: 960px) {
	.in-disqus-util {
		margin-top: -30px;
		margin-bottom: -30px;
	}

	.in-disqus-util .hide-privacy-policy {
		width: 200px;
		left: 100px;
		bottom: -29px;
		background: #f5f7f9;
	}

	.in-disqus-util .hide-share-button {
		height: 20px;
		width: 200px;
		bottom: -42px;
		background: #f5f7f9;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-disqus-util {
		margin-top: -30px;
		margin-bottom: -30px;
	}

	.in-disqus-util .hide-privacy-policy {
		width: 290px;
		left: 105px;
		bottom: -29px;
		background: #f5f7f9;
	}

	.in-disqus-util .hide-share-button {
		height: 22px;
		width: 250px;
		bottom: -45px;
		background: #f5f7f9;
	}
}

.fa,
.fas,
.far,
.fal,
.fad,
.fab {
	-moz-osx-font-smoothing: grayscale;
	-webkit-font-smoothing: antialiased;
	font-style: normal;
	font-variant: normal;
	text-rendering: auto;
	line-height: 1;
}

.fa-lg {
	font-size: 1.33333em;
	line-height: 0.75em;
	vertical-align: -0.0667em;
}

.fa-xs {
	font-size: 0.75em;
}

.fa-sm {
	font-size: 0.875em;
}

.fa-1x {
	font-size: 1em;
}

.fa-2x {
	font-size: 2em;
}

.fa-3x {
	font-size: 3em;
}

.fa-4x {
	font-size: 4em;
}

.fa-5x {
	font-size: 5em;
}

.fa-6x {
	font-size: 6em;
}

.fa-7x {
	font-size: 7em;
}

.fa-8x {
	font-size: 8em;
}

.fa-9x {
	font-size: 9em;
}

.fa-10x {
	font-size: 10em;
}


.fa-500px:before {
	content: "\f26e";
}

.fa-accessible-icon:before {
	content: "\f368";
}

.fa-accusoft:before {
	content: "\f369";
}

.fa-acquisitions-incorporated:before {
	content: "\f6af";
}

.fa-ad:before {
	content: "\f641";
}

.fa-address-book:before {
	content: "\f2b9";
}

.fa-address-card:before {
	content: "\f2bb";
}

.fa-adjust:before {
	content: "\f042";
}

.fa-adn:before {
	content: "\f170";
}

.fa-adversal:before {
	content: "\f36a";
}

.fa-affiliatetheme:before {
	content: "\f36b";
}

.fa-air-freshener:before {
	content: "\f5d0";
}

.fa-airbnb:before {
	content: "\f834";
}

.fa-algolia:before {
	content: "\f36c";
}

.fa-align-center:before {
	content: "\f037";
}

.fa-align-justify:before {
	content: "\f039";
}

.fa-align-left:before {
	content: "\f036";
}

.fa-align-right:before {
	content: "\f038";
}

.fa-alipay:before {
	content: "\f642";
}

.fa-allergies:before {
	content: "\f461";
}

.fa-amazon:before {
	content: "\f270";
}

.fa-amazon-pay:before {
	content: "\f42c";
}

.fa-ambulance:before {
	content: "\f0f9";
}

.fa-american-sign-language-interpreting:before {
	content: "\f2a3";
}

.fa-amilia:before {
	content: "\f36d";
}

.fa-anchor:before {
	content: "\f13d";
}

.fa-android:before {
	content: "\f17b";
}

.fa-angellist:before {
	content: "\f209";
}

.fa-angle-double-down:before {
	content: "\f103";
}

.fa-angle-double-left:before {
	content: "\f100";
}

.fa-angle-double-right:before {
	content: "\f101";
}

.fa-angle-double-up:before {
	content: "\f102";
}

.fa-angle-down:before {
	content: "\f107";
}

.fa-angle-left:before {
	content: "\f104";
}

.fa-angle-right:before {
	content: "\f105";
}

.fa-angle-up:before {
	content: "\f106";
}

.fa-angry:before {
	content: "\f556";
}

.fa-angrycreative:before {
	content: "\f36e";
}

.fa-angular:before {
	content: "\f420";
}

.fa-ankh:before {
	content: "\f644";
}

.fa-app-store:before {
	content: "\f36f";
}

.fa-app-store-ios:before {
	content: "\f370";
}

.fa-apper:before {
	content: "\f371";
}

.fa-apple:before {
	content: "\f179";
}

.fa-apple-alt:before {
	content: "\f5d1";
}

.fa-apple-pay:before {
	content: "\f415";
}

.fa-archive:before {
	content: "\f187";
}

.fa-archway:before {
	content: "\f557";
}

.fa-arrow-alt-circle-down:before {
	content: "\f358";
}

.fa-arrow-alt-circle-left:before {
	content: "\f359";
}

.fa-arrow-alt-circle-right:before {
	content: "\f35a";
}

.fa-arrow-alt-circle-up:before {
	content: "\f35b";
}

.fa-arrow-circle-down:before {
	content: "\f0ab";
}

.fa-arrow-circle-left:before {
	content: "\f0a8";
}

.fa-arrow-circle-right:before {
	content: "\f0a9";
}

.fa-arrow-circle-up:before {
	content: "\f0aa";
}

.fa-arrow-down:before {
	content: "\f063";
}

.fa-arrow-left:before {
	content: "\f060";
}

.fa-arrow-right:before {
	content: "\f061";
}

.fa-arrow-up:before {
	content: "\f062";
}

.fa-arrows-alt:before {
	content: "\f0b2";
}

.fa-arrows-alt-h:before {
	content: "\f337";
}

.fa-arrows-alt-v:before {
	content: "\f338";
}

.fa-artstation:before {
	content: "\f77a";
}

.fa-assistive-listening-systems:before {
	content: "\f2a2";
}

.fa-asterisk:before {
	content: "\f069";
}

.fa-asymmetrik:before {
	content: "\f372";
}

.fa-at:before {
	content: "\f1fa";
}

.fa-atlas:before {
	content: "\f558";
}

.fa-atlassian:before {
	content: "\f77b";
}

.fa-atom:before {
	content: "\f5d2";
}

.fa-audible:before {
	content: "\f373";
}

.fa-audio-description:before {
	content: "\f29e";
}

.fa-autoprefixer:before {
	content: "\f41c";
}

.fa-avianex:before {
	content: "\f374";
}

.fa-aviato:before {
	content: "\f421";
}

.fa-award:before {
	content: "\f559";
}

.fa-aws:before {
	content: "\f375";
}

.fa-baby:before {
	content: "\f77c";
}

.fa-baby-carriage:before {
	content: "\f77d";
}

.fa-backspace:before {
	content: "\f55a";
}

.fa-backward:before {
	content: "\f04a";
}

.fa-bacon:before {
	content: "\f7e5";
}

.fa-bacteria:before {
	content: "\e059";
}

.fa-bacterium:before {
	content: "\e05a";
}

.fa-bahai:before {
	content: "\f666";
}

.fa-balance-scale:before {
	content: "\f24e";
}

.fa-balance-scale-left:before {
	content: "\f515";
}

.fa-balance-scale-right:before {
	content: "\f516";
}

.fa-ban:before {
	content: "\f05e";
}

.fa-band-aid:before {
	content: "\f462";
}

.fa-bandcamp:before {
	content: "\f2d5";
}

.fa-barcode:before {
	content: "\f02a";
}

.fa-bars:before {
	content: "\f0c9";
}

.fa-baseball-ball:before {
	content: "\f433";
}

.fa-basketball-ball:before {
	content: "\f434";
}

.fa-bath:before {
	content: "\f2cd";
}

.fa-battery-empty:before {
	content: "\f244";
}

.fa-battery-full:before {
	content: "\f240";
}

.fa-battery-half:before {
	content: "\f242";
}

.fa-battery-quarter:before {
	content: "\f243";
}

.fa-battery-three-quarters:before {
	content: "\f241";
}

.fa-battle-net:before {
	content: "\f835";
}

.fa-bed:before {
	content: "\f236";
}

.fa-beer:before {
	content: "\f0fc";
}

.fa-behance:before {
	content: "\f1b4";
}

.fa-behance-square:before {
	content: "\f1b5";
}

.fa-bell:before {
	content: "\f0f3";
}

.fa-bell-slash:before {
	content: "\f1f6";
}

.fa-bezier-curve:before {
	content: "\f55b";
}

.fa-bible:before {
	content: "\f647";
}

.fa-bicycle:before {
	content: "\f206";
}

.fa-biking:before {
	content: "\f84a";
}

.fa-bimobject:before {
	content: "\f378";
}

.fa-binoculars:before {
	content: "\f1e5";
}

.fa-biohazard:before {
	content: "\f780";
}

.fa-birthday-cake:before {
	content: "\f1fd";
}

.fa-bitbucket:before {
	content: "\f171";
}

.fa-bitcoin:before {
	content: "\f379";
}

.fa-bity:before {
	content: "\f37a";
}

.fa-black-tie:before {
	content: "\f27e";
}

.fa-blackberry:before {
	content: "\f37b";
}

.fa-blender:before {
	content: "\f517";
}

.fa-blender-phone:before {
	content: "\f6b6";
}

.fa-blind:before {
	content: "\f29d";
}

.fa-blog:before {
	content: "\f781";
}

.fa-blogger:before {
	content: "\f37c";
}

.fa-blogger-b:before {
	content: "\f37d";
}

.fa-bluetooth:before {
	content: "\f293";
}

.fa-bluetooth-b:before {
	content: "\f294";
}

.fa-bold:before {
	content: "\f032";
}

.fa-bolt:before {
	content: "\f0e7";
}

.fa-bomb:before {
	content: "\f1e2";
}

.fa-bone:before {
	content: "\f5d7";
}

.fa-bong:before {
	content: "\f55c";
}

.fa-book:before {
	content: "\f02d";
}

.fa-book-dead:before {
	content: "\f6b7";
}

.fa-book-medical:before {
	content: "\f7e6";
}

.fa-book-open:before {
	content: "\f518";
}

.fa-book-reader:before {
	content: "\f5da";
}

.fa-bookmark:before {
	content: "\f02e";
}

.fa-bootstrap:before {
	content: "\f836";
}

.fa-border-all:before {
	content: "\f84c";
}

.fa-border-none:before {
	content: "\f850";
}

.fa-border-style:before {
	content: "\f853";
}

.fa-bowling-ball:before {
	content: "\f436";
}

.fa-box:before {
	content: "\f466";
}

.fa-box-open:before {
	content: "\f49e";
}

.fa-box-tissue:before {
	content: "\e05b";
}

.fa-boxes:before {
	content: "\f468";
}

.fa-braille:before {
	content: "\f2a1";
}

.fa-brain:before {
	content: "\f5dc";
}

.fa-bread-slice:before {
	content: "\f7ec";
}

.fa-briefcase:before {
	content: "\f0b1";
}

.fa-briefcase-medical:before {
	content: "\f469";
}

.fa-broadcast-tower:before {
	content: "\f519";
}

.fa-broom:before {
	content: "\f51a";
}

.fa-brush:before {
	content: "\f55d";
}

.fa-btc:before {
	content: "\f15a";
}

.fa-buffer:before {
	content: "\f837";
}

.fa-bug:before {
	content: "\f188";
}

.fa-building:before {
	content: "\f1ad";
}

.fa-bullhorn:before {
	content: "\f0a1";
}

.fa-bullseye:before {
	content: "\f140";
}

.fa-burn:before {
	content: "\f46a";
}

.fa-buromobelexperte:before {
	content: "\f37f";
}

.fa-bus:before {
	content: "\f207";
}

.fa-bus-alt:before {
	content: "\f55e";
}

.fa-business-time:before {
	content: "\f64a";
}

.fa-buy-n-large:before {
	content: "\f8a6";
}

.fa-buysellads:before {
	content: "\f20d";
}

.fa-calculator:before {
	content: "\f1ec";
}

.fa-calendar:before {
	content: "\f133";
}

.fa-calendar-alt:before {
	content: "\f073";
}

.fa-calendar-check:before {
	content: "\f274";
}

.fa-calendar-day:before {
	content: "\f783";
}

.fa-calendar-minus:before {
	content: "\f272";
}

.fa-calendar-plus:before {
	content: "\f271";
}

.fa-calendar-times:before {
	content: "\f273";
}

.fa-calendar-week:before {
	content: "\f784";
}

.fa-camera:before {
	content: "\f030";
}

.fa-camera-retro:before {
	content: "\f083";
}

.fa-campground:before {
	content: "\f6bb";
}

.fa-canadian-maple-leaf:before {
	content: "\f785";
}

.fa-candy-cane:before {
	content: "\f786";
}

.fa-cannabis:before {
	content: "\f55f";
}

.fa-capsules:before {
	content: "\f46b";
}

.fa-car:before {
	content: "\f1b9";
}

.fa-car-alt:before {
	content: "\f5de";
}

.fa-car-battery:before {
	content: "\f5df";
}

.fa-car-crash:before {
	content: "\f5e1";
}

.fa-car-side:before {
	content: "\f5e4";
}

.fa-caravan:before {
	content: "\f8ff";
}

.fa-caret-down:before {
	content: "\f0d7";
}

.fa-caret-left:before {
	content: "\f0d9";
}

.fa-caret-right:before {
	content: "\f0da";
}

.fa-caret-square-down:before {
	content: "\f150";
}

.fa-caret-square-left:before {
	content: "\f191";
}

.fa-caret-square-right:before {
	content: "\f152";
}

.fa-caret-square-up:before {
	content: "\f151";
}

.fa-caret-up:before {
	content: "\f0d8";
}

.fa-carrot:before {
	content: "\f787";
}

.fa-cart-arrow-down:before {
	content: "\f218";
}

.fa-cart-plus:before {
	content: "\f217";
}

.fa-cash-register:before {
	content: "\f788";
}

.fa-cat:before {
	content: "\f6be";
}

.fa-cc-amazon-pay:before {
	content: "\f42d";
}

.fa-cc-amex:before {
	content: "\f1f3";
}

.fa-cc-apple-pay:before {
	content: "\f416";
}

.fa-cc-diners-club:before {
	content: "\f24c";
}

.fa-cc-discover:before {
	content: "\f1f2";
}

.fa-cc-jcb:before {
	content: "\f24b";
}

.fa-cc-mastercard:before {
	content: "\f1f1";
}

.fa-cc-paypal:before {
	content: "\f1f4";
}

.fa-cc-stripe:before {
	content: "\f1f5";
}

.fa-cc-visa:before {
	content: "\f1f0";
}

.fa-centercode:before {
	content: "\f380";
}

.fa-centos:before {
	content: "\f789";
}

.fa-certificate:before {
	content: "\f0a3";
}

.fa-chair:before {
	content: "\f6c0";
}

.fa-chalkboard:before {
	content: "\f51b";
}

.fa-chalkboard-teacher:before {
	content: "\f51c";
}

.fa-charging-station:before {
	content: "\f5e7";
}

.fa-chart-area:before {
	content: "\f1fe";
}

.fa-chart-bar:before {
	content: "\f080";
}

.fa-chart-line:before {
	content: "\f201";
}

.fa-chart-pie:before {
	content: "\f200";
}

.fa-check:before {
	content: "\f00c";
}

.fa-check-circle:before {
	content: "\f058";
}

.fa-check-double:before {
	content: "\f560";
}

.fa-check-square:before {
	content: "\f14a";
}

.fa-cheese:before {
	content: "\f7ef";
}

.fa-chess:before {
	content: "\f439";
}

.fa-chess-bishop:before {
	content: "\f43a";
}

.fa-chess-board:before {
	content: "\f43c";
}

.fa-chess-king:before {
	content: "\f43f";
}

.fa-chess-knight:before {
	content: "\f441";
}

.fa-chess-pawn:before {
	content: "\f443";
}

.fa-chess-queen:before {
	content: "\f445";
}

.fa-chess-rook:before {
	content: "\f447";
}

.fa-chevron-circle-down:before {
	content: "\f13a";
}

.fa-chevron-circle-left:before {
	content: "\f137";
}

.fa-chevron-circle-right:before {
	content: "\f138";
}

.fa-chevron-circle-up:before {
	content: "\f139";
}

.fa-chevron-down:before {
	content: "\f078";
}

.fa-chevron-left:before {
	content: "\f053";
}

.fa-chevron-right:before {
	content: "\f054";
}

.fa-chevron-up:before {
	content: "\f077";
}

.fa-child:before {
	content: "\f1ae";
}

.fa-chrome:before {
	content: "\f268";
}

.fa-chromecast:before {
	content: "\f838";
}

.fa-church:before {
	content: "\f51d";
}

.fa-circle:before {
	content: "\f111";
}

.fa-circle-notch:before {
	content: "\f1ce";
}

.fa-city:before {
	content: "\f64f";
}

.fa-clinic-medical:before {
	content: "\f7f2";
}

.fa-clipboard:before {
	content: "\f328";
}

.fa-clipboard-check:before {
	content: "\f46c";
}

.fa-clipboard-list:before {
	content: "\f46d";
}

.fa-clock:before {
	content: "\f017";
}

.fa-clone:before {
	content: "\f24d";
}

.fa-closed-captioning:before {
	content: "\f20a";
}

.fa-cloud:before {
	content: "\f0c2";
}

.fa-cloud-download-alt:before {
	content: "\f381";
}

.fa-cloud-meatball:before {
	content: "\f73b";
}

.fa-cloud-moon:before {
	content: "\f6c3";
}

.fa-cloud-moon-rain:before {
	content: "\f73c";
}

.fa-cloud-rain:before {
	content: "\f73d";
}

.fa-cloud-showers-heavy:before {
	content: "\f740";
}

.fa-cloud-sun:before {
	content: "\f6c4";
}

.fa-cloud-sun-rain:before {
	content: "\f743";
}

.fa-cloud-upload-alt:before {
	content: "\f382";
}

.fa-cloudflare:before {
	content: "\e07d";
}

.fa-cloudscale:before {
	content: "\f383";
}

.fa-cloudsmith:before {
	content: "\f384";
}

.fa-cloudversify:before {
	content: "\f385";
}

.fa-cocktail:before {
	content: "\f561";
}

.fa-code:before {
	content: "\f121";
}

.fa-code-branch:before {
	content: "\f126";
}

.fa-codepen:before {
	content: "\f1cb";
}

.fa-codiepie:before {
	content: "\f284";
}

.fa-coffee:before {
	content: "\f0f4";
}

.fa-cog:before {
	content: "\f013";
}

.fa-cogs:before {
	content: "\f085";
}

.fa-coins:before {
	content: "\f51e";
}

.fa-columns:before {
	content: "\f0db";
}

.fa-comment:before {
	content: "\f075";
}

.fa-comment-alt:before {
	content: "\f27a";
}

.fa-comment-dollar:before {
	content: "\f651";
}

.fa-comment-dots:before {
	content: "\f4ad";
}

.fa-comment-medical:before {
	content: "\f7f5";
}

.fa-comment-slash:before {
	content: "\f4b3";
}

.fa-comments:before {
	content: "\f086";
}

.fa-comments-dollar:before {
	content: "\f653";
}

.fa-compact-disc:before {
	content: "\f51f";
}

.fa-compass:before {
	content: "\f14e";
}

.fa-compress:before {
	content: "\f066";
}

.fa-compress-alt:before {
	content: "\f422";
}

.fa-compress-arrows-alt:before {
	content: "\f78c";
}

.fa-concierge-bell:before {
	content: "\f562";
}

.fa-confluence:before {
	content: "\f78d";
}

.fa-connectdevelop:before {
	content: "\f20e";
}

.fa-contao:before {
	content: "\f26d";
}

.fa-cookie:before {
	content: "\f563";
}

.fa-cookie-bite:before {
	content: "\f564";
}

.fa-copy:before {
	content: "\f0c5";
}

.fa-copyright:before {
	content: "\f1f9";
}

.fa-cotton-bureau:before {
	content: "\f89e";
}

.fa-couch:before {
	content: "\f4b8";
}

.fa-cpanel:before {
	content: "\f388";
}

.fa-creative-commons:before {
	content: "\f25e";
}

.fa-creative-commons-by:before {
	content: "\f4e7";
}

.fa-creative-commons-nc:before {
	content: "\f4e8";
}

.fa-creative-commons-nc-eu:before {
	content: "\f4e9";
}

.fa-creative-commons-nc-jp:before {
	content: "\f4ea";
}

.fa-creative-commons-nd:before {
	content: "\f4eb";
}

.fa-creative-commons-pd:before {
	content: "\f4ec";
}

.fa-creative-commons-pd-alt:before {
	content: "\f4ed";
}

.fa-creative-commons-remix:before {
	content: "\f4ee";
}

.fa-creative-commons-sa:before {
	content: "\f4ef";
}

.fa-creative-commons-sampling:before {
	content: "\f4f0";
}

.fa-creative-commons-sampling-plus:before {
	content: "\f4f1";
}

.fa-creative-commons-share:before {
	content: "\f4f2";
}

.fa-creative-commons-zero:before {
	content: "\f4f3";
}

.fa-credit-card:before {
	content: "\f09d";
}

.fa-critical-role:before {
	content: "\f6c9";
}

.fa-crop:before {
	content: "\f125";
}

.fa-crop-alt:before {
	content: "\f565";
}

.fa-cross:before {
	content: "\f654";
}

.fa-crosshairs:before {
	content: "\f05b";
}

.fa-crow:before {
	content: "\f520";
}

.fa-crown:before {
	content: "\f521";
}

.fa-crutch:before {
	content: "\f7f7";
}

.fa-css3:before {
	content: "\f13c";
}

.fa-css3-alt:before {
	content: "\f38b";
}

.fa-cube:before {
	content: "\f1b2";
}

.fa-cubes:before {
	content: "\f1b3";
}

.fa-cut:before {
	content: "\f0c4";
}

.fa-cuttlefish:before {
	content: "\f38c";
}

.fa-d-and-d:before {
	content: "\f38d";
}

.fa-d-and-d-beyond:before {
	content: "\f6ca";
}

.fa-dailymotion:before {
	content: "\e052";
}

.fa-dashcube:before {
	content: "\f210";
}

.fa-database:before {
	content: "\f1c0";
}

.fa-deaf:before {
	content: "\f2a4";
}

.fa-deezer:before {
	content: "\e077";
}

.fa-delicious:before {
	content: "\f1a5";
}

.fa-democrat:before {
	content: "\f747";
}

.fa-deploydog:before {
	content: "\f38e";
}

.fa-deskpro:before {
	content: "\f38f";
}

.fa-desktop:before {
	content: "\f108";
}

.fa-dev:before {
	content: "\f6cc";
}

.fa-deviantart:before {
	content: "\f1bd";
}

.fa-dharmachakra:before {
	content: "\f655";
}

.fa-dhl:before {
	content: "\f790";
}

.fa-diagnoses:before {
	content: "\f470";
}

.fa-diaspora:before {
	content: "\f791";
}

.fa-dice:before {
	content: "\f522";
}

.fa-dice-d20:before {
	content: "\f6cf";
}

.fa-dice-d6:before {
	content: "\f6d1";
}

.fa-dice-five:before {
	content: "\f523";
}

.fa-dice-four:before {
	content: "\f524";
}

.fa-dice-one:before {
	content: "\f525";
}

.fa-dice-six:before {
	content: "\f526";
}

.fa-dice-three:before {
	content: "\f527";
}

.fa-dice-two:before {
	content: "\f528";
}

.fa-digg:before {
	content: "\f1a6";
}

.fa-digital-ocean:before {
	content: "\f391";
}

.fa-digital-tachograph:before {
	content: "\f566";
}

.fa-directions:before {
	content: "\f5eb";
}

.fa-discord:before {
	content: "\f392";
}

.fa-discourse:before {
	content: "\f393";
}

.fa-disease:before {
	content: "\f7fa";
}

.fa-divide:before {
	content: "\f529";
}

.fa-dizzy:before {
	content: "\f567";
}

.fa-dna:before {
	content: "\f471";
}

.fa-dochub:before {
	content: "\f394";
}

.fa-docker:before {
	content: "\f395";
}

.fa-dog:before {
	content: "\f6d3";
}

.fa-dollar-sign:before {
	content: "\f155";
}

.fa-dolly:before {
	content: "\f472";
}

.fa-dolly-flatbed:before {
	content: "\f474";
}

.fa-donate:before {
	content: "\f4b9";
}

.fa-door-closed:before {
	content: "\f52a";
}

.fa-door-open:before {
	content: "\f52b";
}

.fa-dot-circle:before {
	content: "\f192";
}

.fa-dove:before {
	content: "\f4ba";
}

.fa-download:before {
	content: "\f019";
}

.fa-draft2digital:before {
	content: "\f396";
}

.fa-drafting-compass:before {
	content: "\f568";
}

.fa-dragon:before {
	content: "\f6d5";
}

.fa-draw-polygon:before {
	content: "\f5ee";
}

.fa-dribbble:before {
	content: "\f17d";
}

.fa-dribbble-square:before {
	content: "\f397";
}

.fa-dropbox:before {
	content: "\f16b";
}

.fa-drum:before {
	content: "\f569";
}

.fa-drum-steelpan:before {
	content: "\f56a";
}

.fa-drumstick-bite:before {
	content: "\f6d7";
}

.fa-drupal:before {
	content: "\f1a9";
}

.fa-dumbbell:before {
	content: "\f44b";
}

.fa-dumpster:before {
	content: "\f793";
}

.fa-dumpster-fire:before {
	content: "\f794";
}

.fa-dungeon:before {
	content: "\f6d9";
}

.fa-dyalog:before {
	content: "\f399";
}

.fa-earlybirds:before {
	content: "\f39a";
}

.fa-ebay:before {
	content: "\f4f4";
}

.fa-edge:before {
	content: "\f282";
}

.fa-edge-legacy:before {
	content: "\e078";
}

.fa-edit:before {
	content: "\f044";
}

.fa-egg:before {
	content: "\f7fb";
}

.fa-eject:before {
	content: "\f052";
}

.fa-elementor:before {
	content: "\f430";
}

.fa-ellipsis-h:before {
	content: "\f141";
}

.fa-ellipsis-v:before {
	content: "\f142";
}

.fa-ello:before {
	content: "\f5f1";
}

.fa-ember:before {
	content: "\f423";
}

.fa-empire:before {
	content: "\f1d1";
}

.fa-envelope:before {
	content: "\f0e0";
}

.fa-envelope-open:before {
	content: "\f2b6";
}

.fa-envelope-open-text:before {
	content: "\f658";
}

.fa-envelope-square:before {
	content: "\f199";
}

.fa-envira:before {
	content: "\f299";
}

.fa-equals:before {
	content: "\f52c";
}

.fa-eraser:before {
	content: "\f12d";
}

.fa-erlang:before {
	content: "\f39d";
}

.fa-ethereum:before {
	content: "\f42e";
}

.fa-ethernet:before {
	content: "\f796";
}

.fa-etsy:before {
	content: "\f2d7";
}

.fa-euro-sign:before {
	content: "\f153";
}

.fa-evernote:before {
	content: "\f839";
}

.fa-exchange-alt:before {
	content: "\f362";
}

.fa-exclamation:before {
	content: "\f12a";
}

.fa-exclamation-circle:before {
	content: "\f06a";
}

.fa-exclamation-triangle:before {
	content: "\f071";
}

.fa-expand:before {
	content: "\f065";
}

.fa-expand-alt:before {
	content: "\f424";
}

.fa-expand-arrows-alt:before {
	content: "\f31e";
}

.fa-expeditedssl:before {
	content: "\f23e";
}

.fa-external-link-alt:before {
	content: "\f35d";
}

.fa-external-link-square-alt:before {
	content: "\f360";
}

.fa-eye:before {
	content: "\f06e";
}

.fa-eye-dropper:before {
	content: "\f1fb";
}

.fa-eye-slash:before {
	content: "\f070";
}

.fa-facebook:before {
	content: "\f09a";
}

.fa-facebook-f:before {
	content: "\f39e";
}

.fa-facebook-messenger:before {
	content: "\f39f";
}

.fa-facebook-square:before {
	content: "\f082";
}

.fa-fan:before {
	content: "\f863";
}

.fa-fantasy-flight-games:before {
	content: "\f6dc";
}

.fa-fast-backward:before {
	content: "\f049";
}

.fa-fast-forward:before {
	content: "\f050";
}

.fa-faucet:before {
	content: "\e005";
}

.fa-fax:before {
	content: "\f1ac";
}

.fa-feather:before {
	content: "\f52d";
}

.fa-feather-alt:before {
	content: "\f56b";
}

.fa-fedex:before {
	content: "\f797";
}

.fa-fedora:before {
	content: "\f798";
}

.fa-female:before {
	content: "\f182";
}

.fa-fighter-jet:before {
	content: "\f0fb";
}

.fa-figma:before {
	content: "\f799";
}

.fa-file:before {
	content: "\f15b";
}

.fa-file-alt:before {
	content: "\f15c";
}

.fa-file-archive:before {
	content: "\f1c6";
}

.fa-file-audio:before {
	content: "\f1c7";
}

.fa-file-code:before {
	content: "\f1c9";
}

.fa-file-contract:before {
	content: "\f56c";
}

.fa-file-csv:before {
	content: "\f6dd";
}

.fa-file-download:before {
	content: "\f56d";
}

.fa-file-excel:before {
	content: "\f1c3";
}

.fa-file-export:before {
	content: "\f56e";
}

.fa-file-image:before {
	content: "\f1c5";
}

.fa-file-import:before {
	content: "\f56f";
}

.fa-file-invoice:before {
	content: "\f570";
}

.fa-file-invoice-dollar:before {
	content: "\f571";
}

.fa-file-medical:before {
	content: "\f477";
}

.fa-file-medical-alt:before {
	content: "\f478";
}

.fa-file-pdf:before {
	content: "\f1c1";
}

.fa-file-powerpoint:before {
	content: "\f1c4";
}

.fa-file-prescription:before {
	content: "\f572";
}

.fa-file-signature:before {
	content: "\f573";
}

.fa-file-upload:before {
	content: "\f574";
}

.fa-file-video:before {
	content: "\f1c8";
}

.fa-file-word:before {
	content: "\f1c2";
}

.fa-fill:before {
	content: "\f575";
}

.fa-fill-drip:before {
	content: "\f576";
}

.fa-film:before {
	content: "\f008";
}

.fa-filter:before {
	content: "\f0b0";
}

.fa-fingerprint:before {
	content: "\f577";
}

.fa-fire:before {
	content: "\f06d";
}

.fa-fire-alt:before {
	content: "\f7e4";
}

.fa-fire-extinguisher:before {
	content: "\f134";
}

.fa-firefox:before {
	content: "\f269";
}

.fa-firefox-browser:before {
	content: "\e007";
}

.fa-first-aid:before {
	content: "\f479";
}

.fa-first-order:before {
	content: "\f2b0";
}

.fa-first-order-alt:before {
	content: "\f50a";
}

.fa-firstdraft:before {
	content: "\f3a1";
}

.fa-fish:before {
	content: "\f578";
}

.fa-fist-raised:before {
	content: "\f6de";
}

.fa-flag:before {
	content: "\f024";
}

.fa-flag-checkered:before {
	content: "\f11e";
}

.fa-flag-usa:before {
	content: "\f74d";
}

.fa-flask:before {
	content: "\f0c3";
}

.fa-flickr:before {
	content: "\f16e";
}

.fa-flipboard:before {
	content: "\f44d";
}

.fa-flushed:before {
	content: "\f579";
}

.fa-fly:before {
	content: "\f417";
}

.fa-folder:before {
	content: "\f07b";
}

.fa-folder-minus:before {
	content: "\f65d";
}

.fa-folder-open:before {
	content: "\f07c";
}

.fa-folder-plus:before {
	content: "\f65e";
}

.fa-font:before {
	content: "\f031";
}

.fa-font-awesome:before {
	content: "\f2b4";
}

.fa-font-awesome-alt:before {
	content: "\f35c";
}

.fa-font-awesome-flag:before {
	content: "\f425";
}

.fa-font-awesome-logo-full:before {
	content: "\f4e6";
}

.fa-fonticons:before {
	content: "\f280";
}

.fa-fonticons-fi:before {
	content: "\f3a2";
}

.fa-football-ball:before {
	content: "\f44e";
}

.fa-fort-awesome:before {
	content: "\f286";
}

.fa-fort-awesome-alt:before {
	content: "\f3a3";
}

.fa-forumbee:before {
	content: "\f211";
}

.fa-forward:before {
	content: "\f04e";
}

.fa-foursquare:before {
	content: "\f180";
}

.fa-free-code-camp:before {
	content: "\f2c5";
}

.fa-freebsd:before {
	content: "\f3a4";
}

.fa-frog:before {
	content: "\f52e";
}

.fa-frown:before {
	content: "\f119";
}

.fa-frown-open:before {
	content: "\f57a";
}

.fa-fulcrum:before {
	content: "\f50b";
}

.fa-funnel-dollar:before {
	content: "\f662";
}

.fa-futbol:before {
	content: "\f1e3";
}

.fa-galactic-republic:before {
	content: "\f50c";
}

.fa-galactic-senate:before {
	content: "\f50d";
}

.fa-gamepad:before {
	content: "\f11b";
}

.fa-gas-pump:before {
	content: "\f52f";
}

.fa-gavel:before {
	content: "\f0e3";
}

.fa-gem:before {
	content: "\f3a5";
}

.fa-genderless:before {
	content: "\f22d";
}

.fa-get-pocket:before {
	content: "\f265";
}

.fa-gg:before {
	content: "\f260";
}

.fa-gg-circle:before {
	content: "\f261";
}

.fa-ghost:before {
	content: "\f6e2";
}

.fa-gift:before {
	content: "\f06b";
}

.fa-gifts:before {
	content: "\f79c";
}

.fa-git:before {
	content: "\f1d3";
}

.fa-git-alt:before {
	content: "\f841";
}

.fa-git-square:before {
	content: "\f1d2";
}

.fa-github:before {
	content: "\f09b";
}

.fa-github-alt:before {
	content: "\f113";
}

.fa-github-square:before {
	content: "\f092";
}

.fa-gitkraken:before {
	content: "\f3a6";
}

.fa-gitlab:before {
	content: "\f296";
}

.fa-gitter:before {
	content: "\f426";
}

.fa-glass-cheers:before {
	content: "\f79f";
}

.fa-glass-martini:before {
	content: "\f000";
}

.fa-glass-martini-alt:before {
	content: "\f57b";
}

.fa-glass-whiskey:before {
	content: "\f7a0";
}

.fa-glasses:before {
	content: "\f530";
}

.fa-glide:before {
	content: "\f2a5";
}

.fa-glide-g:before {
	content: "\f2a6";
}

.fa-globe:before {
	content: "\f0ac";
}

.fa-globe-africa:before {
	content: "\f57c";
}

.fa-globe-americas:before {
	content: "\f57d";
}

.fa-globe-asia:before {
	content: "\f57e";
}

.fa-globe-europe:before {
	content: "\f7a2";
}

.fa-gofore:before {
	content: "\f3a7";
}

.fa-golf-ball:before {
	content: "\f450";
}

.fa-goodreads:before {
	content: "\f3a8";
}

.fa-goodreads-g:before {
	content: "\f3a9";
}

.fa-google:before {
	content: "\f1a0";
}

.fa-google-drive:before {
	content: "\f3aa";
}

.fa-google-pay:before {
	content: "\e079";
}

.fa-google-play:before {
	content: "\f3ab";
}

.fa-google-plus:before {
	content: "\f2b3";
}

.fa-google-plus-g:before {
	content: "\f0d5";
}

.fa-google-plus-square:before {
	content: "\f0d4";
}

.fa-google-wallet:before {
	content: "\f1ee";
}

.fa-gopuram:before {
	content: "\f664";
}

.fa-graduation-cap:before {
	content: "\f19d";
}

.fa-gratipay:before {
	content: "\f184";
}

.fa-grav:before {
	content: "\f2d6";
}

.fa-greater-than:before {
	content: "\f531";
}

.fa-greater-than-equal:before {
	content: "\f532";
}

.fa-grimace:before {
	content: "\f57f";
}

.fa-grin:before {
	content: "\f580";
}

.fa-grin-alt:before {
	content: "\f581";
}

.fa-grin-beam:before {
	content: "\f582";
}

.fa-grin-beam-sweat:before {
	content: "\f583";
}

.fa-grin-hearts:before {
	content: "\f584";
}

.fa-grin-squint:before {
	content: "\f585";
}

.fa-grin-squint-tears:before {
	content: "\f586";
}

.fa-grin-stars:before {
	content: "\f587";
}

.fa-grin-tears:before {
	content: "\f588";
}

.fa-grin-tongue:before {
	content: "\f589";
}

.fa-grin-tongue-squint:before {
	content: "\f58a";
}

.fa-grin-tongue-wink:before {
	content: "\f58b";
}

.fa-grin-wink:before {
	content: "\f58c";
}

.fa-grip-horizontal:before {
	content: "\f58d";
}

.fa-grip-lines:before {
	content: "\f7a4";
}

.fa-grip-lines-vertical:before {
	content: "\f7a5";
}

.fa-grip-vertical:before {
	content: "\f58e";
}

.fa-gripfire:before {
	content: "\f3ac";
}

.fa-grunt:before {
	content: "\f3ad";
}

.fa-guilded:before {
	content: "\e07e";
}

.fa-guitar:before {
	content: "\f7a6";
}

.fa-gulp:before {
	content: "\f3ae";
}

.fa-h-square:before {
	content: "\f0fd";
}

.fa-hacker-news:before {
	content: "\f1d4";
}

.fa-hacker-news-square:before {
	content: "\f3af";
}

.fa-hackerrank:before {
	content: "\f5f7";
}

.fa-hamburger:before {
	content: "\f805";
}

.fa-hammer:before {
	content: "\f6e3";
}

.fa-hamsa:before {
	content: "\f665";
}

.fa-hand-holding:before {
	content: "\f4bd";
}

.fa-hand-holding-heart:before {
	content: "\f4be";
}

.fa-hand-holding-medical:before {
	content: "\e05c";
}

.fa-hand-holding-usd:before {
	content: "\f4c0";
}

.fa-hand-holding-water:before {
	content: "\f4c1";
}

.fa-hand-lizard:before {
	content: "\f258";
}

.fa-hand-middle-finger:before {
	content: "\f806";
}

.fa-hand-paper:before {
	content: "\f256";
}

.fa-hand-peace:before {
	content: "\f25b";
}

.fa-hand-point-down:before {
	content: "\f0a7";
}

.fa-hand-point-left:before {
	content: "\f0a5";
}

.fa-hand-point-right:before {
	content: "\f0a4";
}

.fa-hand-point-up:before {
	content: "\f0a6";
}

.fa-hand-pointer:before {
	content: "\f25a";
}

.fa-hand-rock:before {
	content: "\f255";
}

.fa-hand-scissors:before {
	content: "\f257";
}

.fa-hand-sparkles:before {
	content: "\e05d";
}

.fa-hand-spock:before {
	content: "\f259";
}

.fa-hands:before {
	content: "\f4c2";
}

.fa-hands-helping:before {
	content: "\f4c4";
}

.fa-hands-wash:before {
	content: "\e05e";
}

.fa-handshake:before {
	content: "\f2b5";
}

.fa-handshake-alt-slash:before {
	content: "\e05f";
}

.fa-handshake-slash:before {
	content: "\e060";
}

.fa-hanukiah:before {
	content: "\f6e6";
}

.fa-hard-hat:before {
	content: "\f807";
}

.fa-hashtag:before {
	content: "\f292";
}

.fa-hat-cowboy:before {
	content: "\f8c0";
}

.fa-hat-cowboy-side:before {
	content: "\f8c1";
}

.fa-hat-wizard:before {
	content: "\f6e8";
}

.fa-hdd:before {
	content: "\f0a0";
}

.fa-head-side-cough:before {
	content: "\e061";
}

.fa-head-side-cough-slash:before {
	content: "\e062";
}

.fa-head-side-mask:before {
	content: "\e063";
}

.fa-head-side-virus:before {
	content: "\e064";
}

.fa-heading:before {
	content: "\f1dc";
}

.fa-headphones:before {
	content: "\f025";
}

.fa-headphones-alt:before {
	content: "\f58f";
}

.fa-headset:before {
	content: "\f590";
}

.fa-heart:before {
	content: "\f004";
}

.fa-heart-broken:before {
	content: "\f7a9";
}

.fa-heartbeat:before {
	content: "\f21e";
}

.fa-helicopter:before {
	content: "\f533";
}

.fa-highlighter:before {
	content: "\f591";
}

.fa-hiking:before {
	content: "\f6ec";
}

.fa-hippo:before {
	content: "\f6ed";
}

.fa-hips:before {
	content: "\f452";
}

.fa-hire-a-helper:before {
	content: "\f3b0";
}

.fa-history:before {
	content: "\f1da";
}

.fa-hive:before {
	content: "\e07f";
}

.fa-hockey-puck:before {
	content: "\f453";
}

.fa-holly-berry:before {
	content: "\f7aa";
}

.fa-home:before {
	content: "\f015";
}

.fa-hooli:before {
	content: "\f427";
}

.fa-hornbill:before {
	content: "\f592";
}

.fa-horse:before {
	content: "\f6f0";
}

.fa-horse-head:before {
	content: "\f7ab";
}

.fa-hospital:before {
	content: "\f0f8";
}

.fa-hospital-alt:before {
	content: "\f47d";
}

.fa-hospital-symbol:before {
	content: "\f47e";
}

.fa-hospital-user:before {
	content: "\f80d";
}

.fa-hot-tub:before {
	content: "\f593";
}

.fa-hotdog:before {
	content: "\f80f";
}

.fa-hotel:before {
	content: "\f594";
}

.fa-hotjar:before {
	content: "\f3b1";
}

.fa-hourglass:before {
	content: "\f254";
}

.fa-hourglass-end:before {
	content: "\f253";
}

.fa-hourglass-half:before {
	content: "\f252";
}

.fa-hourglass-start:before {
	content: "\f251";
}

.fa-house-damage:before {
	content: "\f6f1";
}

.fa-house-user:before {
	content: "\e065";
}

.fa-houzz:before {
	content: "\f27c";
}

.fa-hryvnia:before {
	content: "\f6f2";
}

.fa-html5:before {
	content: "\f13b";
}

.fa-hubspot:before {
	content: "\f3b2";
}

.fa-i-cursor:before {
	content: "\f246";
}

.fa-ice-cream:before {
	content: "\f810";
}

.fa-icicles:before {
	content: "\f7ad";
}

.fa-icons:before {
	content: "\f86d";
}

.fa-id-badge:before {
	content: "\f2c1";
}

.fa-id-card:before {
	content: "\f2c2";
}

.fa-id-card-alt:before {
	content: "\f47f";
}

.fa-ideal:before {
	content: "\e013";
}

.fa-igloo:before {
	content: "\f7ae";
}

.fa-image:before {
	content: "\f03e";
}

.fa-images:before {
	content: "\f302";
}

.fa-imdb:before {
	content: "\f2d8";
}

.fa-inbox:before {
	content: "\f01c";
}

.fa-indent:before {
	content: "\f03c";
}

.fa-industry:before {
	content: "\f275";
}

.fa-infinity:before {
	content: "\f534";
}

.fa-info:before {
	content: "\f129";
}

.fa-info-circle:before {
	content: "\f05a";
}

.fa-innosoft:before {
	content: "\e080";
}

.fa-instagram:before {
	content: "\f16d";
}

.fa-instagram-square:before {
	content: "\e055";
}

.fa-instalod:before {
	content: "\e081";
}

.fa-intercom:before {
	content: "\f7af";
}

.fa-internet-explorer:before {
	content: "\f26b";
}

.fa-invision:before {
	content: "\f7b0";
}

.fa-ioxhost:before {
	content: "\f208";
}

.fa-italic:before {
	content: "\f033";
}

.fa-itch-io:before {
	content: "\f83a";
}

.fa-itunes:before {
	content: "\f3b4";
}

.fa-itunes-note:before {
	content: "\f3b5";
}

.fa-java:before {
	content: "\f4e4";
}

.fa-jedi:before {
	content: "\f669";
}

.fa-jedi-order:before {
	content: "\f50e";
}

.fa-jenkins:before {
	content: "\f3b6";
}

.fa-jira:before {
	content: "\f7b1";
}

.fa-joget:before {
	content: "\f3b7";
}

.fa-joint:before {
	content: "\f595";
}

.fa-joomla:before {
	content: "\f1aa";
}

.fa-journal-whills:before {
	content: "\f66a";
}

.fa-js:before {
	content: "\f3b8";
}

.fa-js-square:before {
	content: "\f3b9";
}

.fa-jsfiddle:before {
	content: "\f1cc";
}

.fa-kaaba:before {
	content: "\f66b";
}

.fa-kaggle:before {
	content: "\f5fa";
}

.fa-key:before {
	content: "\f084";
}

.fa-keybase:before {
	content: "\f4f5";
}

.fa-keyboard:before {
	content: "\f11c";
}

.fa-keycdn:before {
	content: "\f3ba";
}

.fa-khanda:before {
	content: "\f66d";
}

.fa-kickstarter:before {
	content: "\f3bb";
}

.fa-kickstarter-k:before {
	content: "\f3bc";
}

.fa-kiss:before {
	content: "\f596";
}

.fa-kiss-beam:before {
	content: "\f597";
}

.fa-kiss-wink-heart:before {
	content: "\f598";
}

.fa-kiwi-bird:before {
	content: "\f535";
}

.fa-korvue:before {
	content: "\f42f";
}

.fa-landmark:before {
	content: "\f66f";
}

.fa-language:before {
	content: "\f1ab";
}

.fa-laptop:before {
	content: "\f109";
}

.fa-laptop-code:before {
	content: "\f5fc";
}

.fa-laptop-house:before {
	content: "\e066";
}

.fa-laptop-medical:before {
	content: "\f812";
}

.fa-laravel:before {
	content: "\f3bd";
}

.fa-lastfm:before {
	content: "\f202";
}

.fa-lastfm-square:before {
	content: "\f203";
}

.fa-laugh:before {
	content: "\f599";
}

.fa-laugh-beam:before {
	content: "\f59a";
}

.fa-laugh-squint:before {
	content: "\f59b";
}

.fa-laugh-wink:before {
	content: "\f59c";
}

.fa-layer-group:before {
	content: "\f5fd";
}

.fa-leaf:before {
	content: "\f06c";
}

.fa-leanpub:before {
	content: "\f212";
}

.fa-lemon:before {
	content: "\f094";
}

.fa-less:before {
	content: "\f41d";
}

.fa-less-than:before {
	content: "\f536";
}

.fa-less-than-equal:before {
	content: "\f537";
}

.fa-level-down-alt:before {
	content: "\f3be";
}

.fa-level-up-alt:before {
	content: "\f3bf";
}

.fa-life-ring:before {
	content: "\f1cd";
}

.fa-lightbulb:before {
	content: "\f0eb";
}

.fa-line:before {
	content: "\f3c0";
}

.fa-link:before {
	content: "\f0c1";
}

.fa-linkedin:before {
	content: "\f08c";
}

.fa-linkedin-in:before {
	content: "\f0e1";
}

.fa-linode:before {
	content: "\f2b8";
}

.fa-linux:before {
	content: "\f17c";
}

.fa-lira-sign:before {
	content: "\f195";
}

.fa-list:before {
	content: "\f03a";
}

.fa-list-alt:before {
	content: "\f022";
}

.fa-list-ol:before {
	content: "\f0cb";
}

.fa-list-ul:before {
	content: "\f0ca";
}

.fa-location-arrow:before {
	content: "\f124";
}

.fa-lock:before {
	content: "\f023";
}

.fa-lock-open:before {
	content: "\f3c1";
}

.fa-long-arrow-alt-down:before {
	content: "\f309";
}

.fa-long-arrow-alt-left:before {
	content: "\f30a";
}

.fa-long-arrow-alt-right:before {
	content: "\f30b";
}

.fa-long-arrow-alt-up:before {
	content: "\f30c";
}

.fa-low-vision:before {
	content: "\f2a8";
}

.fa-luggage-cart:before {
	content: "\f59d";
}

.fa-lungs:before {
	content: "\f604";
}

.fa-lungs-virus:before {
	content: "\e067";
}

.fa-lyft:before {
	content: "\f3c3";
}

.fa-magento:before {
	content: "\f3c4";
}

.fa-magic:before {
	content: "\f0d0";
}

.fa-magnet:before {
	content: "\f076";
}

.fa-mail-bulk:before {
	content: "\f674";
}

.fa-mailchimp:before {
	content: "\f59e";
}

.fa-male:before {
	content: "\f183";
}

.fa-mandalorian:before {
	content: "\f50f";
}

.fa-map:before {
	content: "\f279";
}

.fa-map-marked:before {
	content: "\f59f";
}

.fa-map-marked-alt:before {
	content: "\f5a0";
}

.fa-map-marker:before {
	content: "\f041";
}

.fa-map-marker-alt:before {
	content: "\f3c5";
}

.fa-map-pin:before {
	content: "\f276";
}

.fa-map-signs:before {
	content: "\f277";
}

.fa-markdown:before {
	content: "\f60f";
}

.fa-marker:before {
	content: "\f5a1";
}

.fa-mars:before {
	content: "\f222";
}

.fa-mars-double:before {
	content: "\f227";
}

.fa-mars-stroke:before {
	content: "\f229";
}

.fa-mars-stroke-h:before {
	content: "\f22b";
}

.fa-mars-stroke-v:before {
	content: "\f22a";
}

.fa-mask:before {
	content: "\f6fa";
}

.fa-mastodon:before {
	content: "\f4f6";
}

.fa-maxcdn:before {
	content: "\f136";
}

.fa-mdb:before {
	content: "\f8ca";
}

.fa-medal:before {
	content: "\f5a2";
}

.fa-medapps:before {
	content: "\f3c6";
}

.fa-medium:before {
	content: "\f23a";
}

.fa-medium-m:before {
	content: "\f3c7";
}

.fa-medkit:before {
	content: "\f0fa";
}

.fa-medrt:before {
	content: "\f3c8";
}

.fa-meetup:before {
	content: "\f2e0";
}

.fa-megaport:before {
	content: "\f5a3";
}

.fa-meh:before {
	content: "\f11a";
}

.fa-meh-blank:before {
	content: "\f5a4";
}

.fa-meh-rolling-eyes:before {
	content: "\f5a5";
}

.fa-memory:before {
	content: "\f538";
}

.fa-mendeley:before {
	content: "\f7b3";
}

.fa-menorah:before {
	content: "\f676";
}

.fa-mercury:before {
	content: "\f223";
}

.fa-meteor:before {
	content: "\f753";
}

.fa-microblog:before {
	content: "\e01a";
}

.fa-microchip:before {
	content: "\f2db";
}

.fa-microphone:before {
	content: "\f130";
}

.fa-microphone-alt:before {
	content: "\f3c9";
}

.fa-microphone-alt-slash:before {
	content: "\f539";
}

.fa-microphone-slash:before {
	content: "\f131";
}

.fa-microscope:before {
	content: "\f610";
}

.fa-microsoft:before {
	content: "\f3ca";
}

.fa-minus:before {
	content: "\f068";
}

.fa-minus-circle:before {
	content: "\f056";
}

.fa-minus-square:before {
	content: "\f146";
}

.fa-mitten:before {
	content: "\f7b5";
}

.fa-mix:before {
	content: "\f3cb";
}

.fa-mixcloud:before {
	content: "\f289";
}

.fa-mixer:before {
	content: "\e056";
}

.fa-mizuni:before {
	content: "\f3cc";
}

.fa-mobile:before {
	content: "\f10b";
}

.fa-mobile-alt:before {
	content: "\f3cd";
}

.fa-modx:before {
	content: "\f285";
}

.fa-monero:before {
	content: "\f3d0";
}

.fa-money-bill:before {
	content: "\f0d6";
}

.fa-money-bill-alt:before {
	content: "\f3d1";
}

.fa-money-bill-wave:before {
	content: "\f53a";
}

.fa-money-bill-wave-alt:before {
	content: "\f53b";
}

.fa-money-check:before {
	content: "\f53c";
}

.fa-money-check-alt:before {
	content: "\f53d";
}

.fa-monument:before {
	content: "\f5a6";
}

.fa-moon:before {
	content: "\f186";
}

.fa-mortar-pestle:before {
	content: "\f5a7";
}

.fa-mosque:before {
	content: "\f678";
}

.fa-motorcycle:before {
	content: "\f21c";
}

.fa-mountain:before {
	content: "\f6fc";
}

.fa-mouse:before {
	content: "\f8cc";
}

.fa-mouse-pointer:before {
	content: "\f245";
}

.fa-mug-hot:before {
	content: "\f7b6";
}

.fa-music:before {
	content: "\f001";
}

.fa-napster:before {
	content: "\f3d2";
}

.fa-neos:before {
	content: "\f612";
}

.fa-network-wired:before {
	content: "\f6ff";
}

.fa-neuter:before {
	content: "\f22c";
}

.fa-newspaper:before {
	content: "\f1ea";
}

.fa-nimblr:before {
	content: "\f5a8";
}

.fa-node:before {
	content: "\f419";
}

.fa-node-js:before {
	content: "\f3d3";
}

.fa-not-equal:before {
	content: "\f53e";
}

.fa-notes-medical:before {
	content: "\f481";
}

.fa-npm:before {
	content: "\f3d4";
}

.fa-ns8:before {
	content: "\f3d5";
}

.fa-nutritionix:before {
	content: "\f3d6";
}

.fa-object-group:before {
	content: "\f247";
}

.fa-object-ungroup:before {
	content: "\f248";
}

.fa-octopus-deploy:before {
	content: "\e082";
}

.fa-odnoklassniki:before {
	content: "\f263";
}

.fa-odnoklassniki-square:before {
	content: "\f264";
}

.fa-oil-can:before {
	content: "\f613";
}

.fa-old-republic:before {
	content: "\f510";
}

.fa-om:before {
	content: "\f679";
}

.fa-opencart:before {
	content: "\f23d";
}

.fa-openid:before {
	content: "\f19b";
}

.fa-opera:before {
	content: "\f26a";
}

.fa-optin-monster:before {
	content: "\f23c";
}

.fa-orcid:before {
	content: "\f8d2";
}

.fa-osi:before {
	content: "\f41a";
}

.fa-otter:before {
	content: "\f700";
}

.fa-outdent:before {
	content: "\f03b";
}

.fa-page4:before {
	content: "\f3d7";
}

.fa-pagelines:before {
	content: "\f18c";
}

.fa-pager:before {
	content: "\f815";
}

.fa-paint-brush:before {
	content: "\f1fc";
}

.fa-paint-roller:before {
	content: "\f5aa";
}

.fa-palette:before {
	content: "\f53f";
}

.fa-palfed:before {
	content: "\f3d8";
}

.fa-pallet:before {
	content: "\f482";
}

.fa-paper-plane:before {
	content: "\f1d8";
}

.fa-paperclip:before {
	content: "\f0c6";
}

.fa-parachute-box:before {
	content: "\f4cd";
}

.fa-paragraph:before {
	content: "\f1dd";
}

.fa-parking:before {
	content: "\f540";
}

.fa-passport:before {
	content: "\f5ab";
}

.fa-pastafarianism:before {
	content: "\f67b";
}

.fa-paste:before {
	content: "\f0ea";
}

.fa-patreon:before {
	content: "\f3d9";
}

.fa-pause:before {
	content: "\f04c";
}

.fa-pause-circle:before {
	content: "\f28b";
}

.fa-paw:before {
	content: "\f1b0";
}

.fa-paypal:before {
	content: "\f1ed";
}

.fa-peace:before {
	content: "\f67c";
}

.fa-pen:before {
	content: "\f304";
}

.fa-pen-alt:before {
	content: "\f305";
}

.fa-pen-fancy:before {
	content: "\f5ac";
}

.fa-pen-nib:before {
	content: "\f5ad";
}

.fa-pen-square:before {
	content: "\f14b";
}

.fa-pencil-alt:before {
	content: "\f303";
}

.fa-pencil-ruler:before {
	content: "\f5ae";
}

.fa-penny-arcade:before {
	content: "\f704";
}

.fa-people-arrows:before {
	content: "\e068";
}

.fa-people-carry:before {
	content: "\f4ce";
}

.fa-pepper-hot:before {
	content: "\f816";
}

.fa-perbyte:before {
	content: "\e083";
}

.fa-percent:before {
	content: "\f295";
}

.fa-percentage:before {
	content: "\f541";
}

.fa-periscope:before {
	content: "\f3da";
}

.fa-person-booth:before {
	content: "\f756";
}

.fa-phabricator:before {
	content: "\f3db";
}

.fa-phoenix-framework:before {
	content: "\f3dc";
}

.fa-phoenix-squadron:before {
	content: "\f511";
}

.fa-phone:before {
	content: "\f095";
}

.fa-phone-alt:before {
	content: "\f879";
}

.fa-phone-slash:before {
	content: "\f3dd";
}

.fa-phone-square:before {
	content: "\f098";
}

.fa-phone-square-alt:before {
	content: "\f87b";
}

.fa-phone-volume:before {
	content: "\f2a0";
}

.fa-photo-video:before {
	content: "\f87c";
}

.fa-php:before {
	content: "\f457";
}

.fa-pied-piper:before {
	content: "\f2ae";
}

.fa-pied-piper-alt:before {
	content: "\f1a8";
}

.fa-pied-piper-hat:before {
	content: "\f4e5";
}

.fa-pied-piper-pp:before {
	content: "\f1a7";
}

.fa-pied-piper-square:before {
	content: "\e01e";
}

.fa-piggy-bank:before {
	content: "\f4d3";
}

.fa-pills:before {
	content: "\f484";
}

.fa-pinterest:before {
	content: "\f0d2";
}

.fa-pinterest-p:before {
	content: "\f231";
}

.fa-pinterest-square:before {
	content: "\f0d3";
}

.fa-pizza-slice:before {
	content: "\f818";
}

.fa-place-of-worship:before {
	content: "\f67f";
}

.fa-plane:before {
	content: "\f072";
}

.fa-plane-arrival:before {
	content: "\f5af";
}

.fa-plane-departure:before {
	content: "\f5b0";
}

.fa-plane-slash:before {
	content: "\e069";
}

.fa-play:before {
	content: "\f04b";
}

.fa-play-circle:before {
	content: "\f144";
}

.fa-playstation:before {
	content: "\f3df";
}

.fa-plug:before {
	content: "\f1e6";
}

.fa-plus:before {
	content: "\f067";
}

.fa-plus-circle:before {
	content: "\f055";
}

.fa-plus-square:before {
	content: "\f0fe";
}

.fa-podcast:before {
	content: "\f2ce";
}

.fa-poll:before {
	content: "\f681";
}

.fa-poll-h:before {
	content: "\f682";
}

.fa-poo:before {
	content: "\f2fe";
}

.fa-poo-storm:before {
	content: "\f75a";
}

.fa-poop:before {
	content: "\f619";
}

.fa-portrait:before {
	content: "\f3e0";
}

.fa-pound-sign:before {
	content: "\f154";
}

.fa-power-off:before {
	content: "\f011";
}

.fa-pray:before {
	content: "\f683";
}

.fa-praying-hands:before {
	content: "\f684";
}

.fa-prescription:before {
	content: "\f5b1";
}

.fa-prescription-bottle:before {
	content: "\f485";
}

.fa-prescription-bottle-alt:before {
	content: "\f486";
}

.fa-print:before {
	content: "\f02f";
}

.fa-procedures:before {
	content: "\f487";
}

.fa-product-hunt:before {
	content: "\f288";
}

.fa-project-diagram:before {
	content: "\f542";
}

.fa-pump-medical:before {
	content: "\e06a";
}

.fa-pump-soap:before {
	content: "\e06b";
}

.fa-pushed:before {
	content: "\f3e1";
}

.fa-puzzle-piece:before {
	content: "\f12e";
}

.fa-python:before {
	content: "\f3e2";
}

.fa-qq:before {
	content: "\f1d6";
}

.fa-qrcode:before {
	content: "\f029";
}

.fa-question:before {
	content: "\f128";
}

.fa-question-circle:before {
	content: "\f059";
}

.fa-quidditch:before {
	content: "\f458";
}

.fa-quinscape:before {
	content: "\f459";
}

.fa-quora:before {
	content: "\f2c4";
}

.fa-quote-left:before {
	content: "\f10d";
}

.fa-quote-right:before {
	content: "\f10e";
}

.fa-quran:before {
	content: "\f687";
}

.fa-r-project:before {
	content: "\f4f7";
}

.fa-radiation:before {
	content: "\f7b9";
}

.fa-radiation-alt:before {
	content: "\f7ba";
}

.fa-rainbow:before {
	content: "\f75b";
}

.fa-random:before {
	content: "\f074";
}

.fa-raspberry-pi:before {
	content: "\f7bb";
}

.fa-ravelry:before {
	content: "\f2d9";
}

.fa-react:before {
	content: "\f41b";
}

.fa-reacteurope:before {
	content: "\f75d";
}

.fa-readme:before {
	content: "\f4d5";
}

.fa-rebel:before {
	content: "\f1d0";
}

.fa-receipt:before {
	content: "\f543";
}

.fa-record-vinyl:before {
	content: "\f8d9";
}

.fa-recycle:before {
	content: "\f1b8";
}

.fa-red-river:before {
	content: "\f3e3";
}

.fa-reddit:before {
	content: "\f1a1";
}

.fa-reddit-alien:before {
	content: "\f281";
}

.fa-reddit-square:before {
	content: "\f1a2";
}

.fa-redhat:before {
	content: "\f7bc";
}

.fa-redo:before {
	content: "\f01e";
}

.fa-redo-alt:before {
	content: "\f2f9";
}

.fa-registered:before {
	content: "\f25d";
}

.fa-remove-format:before {
	content: "\f87d";
}

.fa-renren:before {
	content: "\f18b";
}

.fa-reply:before {
	content: "\f3e5";
}

.fa-reply-all:before {
	content: "\f122";
}

.fa-replyd:before {
	content: "\f3e6";
}

.fa-republican:before {
	content: "\f75e";
}

.fa-researchgate:before {
	content: "\f4f8";
}

.fa-resolving:before {
	content: "\f3e7";
}

.fa-restroom:before {
	content: "\f7bd";
}

.fa-retweet:before {
	content: "\f079";
}

.fa-rev:before {
	content: "\f5b2";
}

.fa-ribbon:before {
	content: "\f4d6";
}

.fa-ring:before {
	content: "\f70b";
}

.fa-road:before {
	content: "\f018";
}

.fa-robot:before {
	content: "\f544";
}

.fa-rocket:before {
	content: "\f135";
}

.fa-rocketchat:before {
	content: "\f3e8";
}

.fa-rockrms:before {
	content: "\f3e9";
}

.fa-route:before {
	content: "\f4d7";
}

.fa-rss:before {
	content: "\f09e";
}

.fa-rss-square:before {
	content: "\f143";
}

.fa-ruble-sign:before {
	content: "\f158";
}

.fa-ruler:before {
	content: "\f545";
}

.fa-ruler-combined:before {
	content: "\f546";
}

.fa-ruler-horizontal:before {
	content: "\f547";
}

.fa-ruler-vertical:before {
	content: "\f548";
}

.fa-running:before {
	content: "\f70c";
}

.fa-rupee-sign:before {
	content: "\f156";
}

.fa-rust:before {
	content: "\e07a";
}

.fa-sad-cry:before {
	content: "\f5b3";
}

.fa-sad-tear:before {
	content: "\f5b4";
}

.fa-safari:before {
	content: "\f267";
}

.fa-salesforce:before {
	content: "\f83b";
}

.fa-sass:before {
	content: "\f41e";
}

.fa-satellite:before {
	content: "\f7bf";
}

.fa-satellite-dish:before {
	content: "\f7c0";
}

.fa-save:before {
	content: "\f0c7";
}

.fa-schlix:before {
	content: "\f3ea";
}

.fa-school:before {
	content: "\f549";
}

.fa-screwdriver:before {
	content: "\f54a";
}

.fa-scribd:before {
	content: "\f28a";
}

.fa-scroll:before {
	content: "\f70e";
}

.fa-sd-card:before {
	content: "\f7c2";
}

.fa-search:before {
	content: "\f002";
}

.fa-search-dollar:before {
	content: "\f688";
}

.fa-search-location:before {
	content: "\f689";
}

.fa-search-minus:before {
	content: "\f010";
}

.fa-search-plus:before {
	content: "\f00e";
}

.fa-searchengin:before {
	content: "\f3eb";
}

.fa-seedling:before {
	content: "\f4d8";
}

.fa-sellcast:before {
	content: "\f2da";
}

.fa-sellsy:before {
	content: "\f213";
}

.fa-server:before {
	content: "\f233";
}

.fa-servicestack:before {
	content: "\f3ec";
}

.fa-shapes:before {
	content: "\f61f";
}

.fa-share:before {
	content: "\f064";
}

.fa-share-alt:before {
	content: "\f1e0";
}

.fa-share-alt-square:before {
	content: "\f1e1";
}

.fa-share-square:before {
	content: "\f14d";
}

.fa-shekel-sign:before {
	content: "\f20b";
}

.fa-shield-alt:before {
	content: "\f3ed";
}

.fa-shield-virus:before {
	content: "\e06c";
}

.fa-ship:before {
	content: "\f21a";
}

.fa-shipping-fast:before {
	content: "\f48b";
}

.fa-shirtsinbulk:before {
	content: "\f214";
}

.fa-shoe-prints:before {
	content: "\f54b";
}

.fa-shopify:before {
	content: "\e057";
}

.fa-shopping-bag:before {
	content: "\f290";
}

.fa-shopping-basket:before {
	content: "\f291";
}

.fa-shopping-cart:before {
	content: "\f07a";
}

.fa-shopware:before {
	content: "\f5b5";
}

.fa-shower:before {
	content: "\f2cc";
}

.fa-shuttle-van:before {
	content: "\f5b6";
}

.fa-sign:before {
	content: "\f4d9";
}

.fa-sign-in-alt:before {
	content: "\f2f6";
}

.fa-sign-language:before {
	content: "\f2a7";
}

.fa-sign-out-alt:before {
	content: "\f2f5";
}

.fa-signal:before {
	content: "\f012";
}

.fa-signature:before {
	content: "\f5b7";
}

.fa-sim-card:before {
	content: "\f7c4";
}

.fa-simplybuilt:before {
	content: "\f215";
}

.fa-sink:before {
	content: "\e06d";
}

.fa-sistrix:before {
	content: "\f3ee";
}

.fa-sitemap:before {
	content: "\f0e8";
}

.fa-sith:before {
	content: "\f512";
}

.fa-skating:before {
	content: "\f7c5";
}

.fa-sketch:before {
	content: "\f7c6";
}

.fa-skiing:before {
	content: "\f7c9";
}

.fa-skiing-nordic:before {
	content: "\f7ca";
}

.fa-skull:before {
	content: "\f54c";
}

.fa-skull-crossbones:before {
	content: "\f714";
}

.fa-skyatlas:before {
	content: "\f216";
}

.fa-skype:before {
	content: "\f17e";
}

.fa-slack:before {
	content: "\f198";
}

.fa-slack-hash:before {
	content: "\f3ef";
}

.fa-slash:before {
	content: "\f715";
}

.fa-sleigh:before {
	content: "\f7cc";
}

.fa-sliders-h:before {
	content: "\f1de";
}

.fa-slideshare:before {
	content: "\f1e7";
}

.fa-smile:before {
	content: "\f118";
}

.fa-smile-beam:before {
	content: "\f5b8";
}

.fa-smile-wink:before {
	content: "\f4da";
}

.fa-smog:before {
	content: "\f75f";
}

.fa-smoking:before {
	content: "\f48d";
}

.fa-smoking-ban:before {
	content: "\f54d";
}

.fa-sms:before {
	content: "\f7cd";
}

.fa-snapchat:before {
	content: "\f2ab";
}

.fa-snapchat-ghost:before {
	content: "\f2ac";
}

.fa-snapchat-square:before {
	content: "\f2ad";
}

.fa-snowboarding:before {
	content: "\f7ce";
}

.fa-snowflake:before {
	content: "\f2dc";
}

.fa-snowman:before {
	content: "\f7d0";
}

.fa-snowplow:before {
	content: "\f7d2";
}

.fa-soap:before {
	content: "\e06e";
}

.fa-socks:before {
	content: "\f696";
}

.fa-solar-panel:before {
	content: "\f5ba";
}

.fa-sort:before {
	content: "\f0dc";
}

.fa-sort-alpha-down:before {
	content: "\f15d";
}

.fa-sort-alpha-down-alt:before {
	content: "\f881";
}

.fa-sort-alpha-up:before {
	content: "\f15e";
}

.fa-sort-alpha-up-alt:before {
	content: "\f882";
}

.fa-sort-amount-down:before {
	content: "\f160";
}

.fa-sort-amount-down-alt:before {
	content: "\f884";
}

.fa-sort-amount-up:before {
	content: "\f161";
}

.fa-sort-amount-up-alt:before {
	content: "\f885";
}

.fa-sort-down:before {
	content: "\f0dd";
}

.fa-sort-numeric-down:before {
	content: "\f162";
}

.fa-sort-numeric-down-alt:before {
	content: "\f886";
}

.fa-sort-numeric-up:before {
	content: "\f163";
}

.fa-sort-numeric-up-alt:before {
	content: "\f887";
}

.fa-sort-up:before {
	content: "\f0de";
}

.fa-soundcloud:before {
	content: "\f1be";
}

.fa-sourcetree:before {
	content: "\f7d3";
}

.fa-spa:before {
	content: "\f5bb";
}

.fa-space-shuttle:before {
	content: "\f197";
}

.fa-speakap:before {
	content: "\f3f3";
}

.fa-speaker-deck:before {
	content: "\f83c";
}

.fa-spell-check:before {
	content: "\f891";
}

.fa-spider:before {
	content: "\f717";
}

.fa-spinner:before {
	content: "\f110";
}

.fa-splotch:before {
	content: "\f5bc";
}

.fa-spotify:before {
	content: "\f1bc";
}

.fa-spray-can:before {
	content: "\f5bd";
}

.fa-square:before {
	content: "\f0c8";
}

.fa-square-full:before {
	content: "\f45c";
}

.fa-square-root-alt:before {
	content: "\f698";
}

.fa-squarespace:before {
	content: "\f5be";
}

.fa-stack-exchange:before {
	content: "\f18d";
}

.fa-stack-overflow:before {
	content: "\f16c";
}

.fa-stackpath:before {
	content: "\f842";
}

.fa-stamp:before {
	content: "\f5bf";
}

.fa-star:before {
	content: "\f005";
}

.fa-star-and-crescent:before {
	content: "\f699";
}

.fa-star-half:before {
	content: "\f089";
}

.fa-star-half-alt:before {
	content: "\f5c0";
}

.fa-star-of-david:before {
	content: "\f69a";
}

.fa-star-of-life:before {
	content: "\f621";
}

.fa-staylinked:before {
	content: "\f3f5";
}

.fa-steam:before {
	content: "\f1b6";
}

.fa-steam-square:before {
	content: "\f1b7";
}

.fa-steam-symbol:before {
	content: "\f3f6";
}

.fa-step-backward:before {
	content: "\f048";
}

.fa-step-forward:before {
	content: "\f051";
}

.fa-stethoscope:before {
	content: "\f0f1";
}

.fa-sticker-mule:before {
	content: "\f3f7";
}

.fa-sticky-note:before {
	content: "\f249";
}

.fa-stop:before {
	content: "\f04d";
}

.fa-stop-circle:before {
	content: "\f28d";
}

.fa-stopwatch:before {
	content: "\f2f2";
}

.fa-stopwatch-20:before {
	content: "\e06f";
}

.fa-store:before {
	content: "\f54e";
}

.fa-store-alt:before {
	content: "\f54f";
}

.fa-store-alt-slash:before {
	content: "\e070";
}

.fa-store-slash:before {
	content: "\e071";
}

.fa-strava:before {
	content: "\f428";
}

.fa-stream:before {
	content: "\f550";
}

.fa-street-view:before {
	content: "\f21d";
}

.fa-strikethrough:before {
	content: "\f0cc";
}

.fa-stripe:before {
	content: "\f429";
}

.fa-stripe-s:before {
	content: "\f42a";
}

.fa-stroopwafel:before {
	content: "\f551";
}

.fa-studiovinari:before {
	content: "\f3f8";
}

.fa-stumbleupon:before {
	content: "\f1a4";
}

.fa-stumbleupon-circle:before {
	content: "\f1a3";
}

.fa-subscript:before {
	content: "\f12c";
}

.fa-subway:before {
	content: "\f239";
}

.fa-suitcase:before {
	content: "\f0f2";
}

.fa-suitcase-rolling:before {
	content: "\f5c1";
}

.fa-sun:before {
	content: "\f185";
}

.fa-superpowers:before {
	content: "\f2dd";
}

.fa-superscript:before {
	content: "\f12b";
}

.fa-supple:before {
	content: "\f3f9";
}

.fa-surprise:before {
	content: "\f5c2";
}

.fa-suse:before {
	content: "\f7d6";
}

.fa-swatchbook:before {
	content: "\f5c3";
}

.fa-swift:before {
	content: "\f8e1";
}

.fa-swimmer:before {
	content: "\f5c4";
}

.fa-swimming-pool:before {
	content: "\f5c5";
}

.fa-symfony:before {
	content: "\f83d";
}

.fa-synagogue:before {
	content: "\f69b";
}

.fa-sync:before {
	content: "\f021";
}

.fa-sync-alt:before {
	content: "\f2f1";
}

.fa-syringe:before {
	content: "\f48e";
}

.fa-table:before {
	content: "\f0ce";
}

.fa-table-tennis:before {
	content: "\f45d";
}

.fa-tablet:before {
	content: "\f10a";
}

.fa-tablet-alt:before {
	content: "\f3fa";
}

.fa-tablets:before {
	content: "\f490";
}

.fa-tachometer-alt:before {
	content: "\f3fd";
}

.fa-tag:before {
	content: "\f02b";
}

.fa-tags:before {
	content: "\f02c";
}

.fa-tape:before {
	content: "\f4db";
}

.fa-tasks:before {
	content: "\f0ae";
}

.fa-taxi:before {
	content: "\f1ba";
}

.fa-teamspeak:before {
	content: "\f4f9";
}

.fa-teeth:before {
	content: "\f62e";
}

.fa-teeth-open:before {
	content: "\f62f";
}

.fa-telegram:before {
	content: "\f2c6";
}

.fa-telegram-plane:before {
	content: "\f3fe";
}

.fa-temperature-high:before {
	content: "\f769";
}

.fa-temperature-low:before {
	content: "\f76b";
}

.fa-tencent-weibo:before {
	content: "\f1d5";
}

.fa-tenge:before {
	content: "\f7d7";
}

.fa-terminal:before {
	content: "\f120";
}

.fa-text-height:before {
	content: "\f034";
}

.fa-text-width:before {
	content: "\f035";
}

.fa-th:before {
	content: "\f00a";
}

.fa-th-large:before {
	content: "\f009";
}

.fa-th-list:before {
	content: "\f00b";
}

.fa-the-red-yeti:before {
	content: "\f69d";
}

.fa-theater-masks:before {
	content: "\f630";
}

.fa-themeco:before {
	content: "\f5c6";
}

.fa-themeisle:before {
	content: "\f2b2";
}

.fa-thermometer:before {
	content: "\f491";
}

.fa-thermometer-empty:before {
	content: "\f2cb";
}

.fa-thermometer-full:before {
	content: "\f2c7";
}

.fa-thermometer-half:before {
	content: "\f2c9";
}

.fa-thermometer-quarter:before {
	content: "\f2ca";
}

.fa-thermometer-three-quarters:before {
	content: "\f2c8";
}

.fa-think-peaks:before {
	content: "\f731";
}

.fa-thumbs-down:before {
	content: "\f165";
}

.fa-thumbs-up:before {
	content: "\f164";
}

.fa-thumbtack:before {
	content: "\f08d";
}

.fa-ticket-alt:before {
	content: "\f3ff";
}

.fa-tiktok:before {
	content: "\e07b";
}

.fa-times:before {
	content: "\f00d";
}

.fa-times-circle:before {
	content: "\f057";
}

.fa-tint:before {
	content: "\f043";
}

.fa-tint-slash:before {
	content: "\f5c7";
}

.fa-tired:before {
	content: "\f5c8";
}

.fa-toggle-off:before {
	content: "\f204";
}

.fa-toggle-on:before {
	content: "\f205";
}

.fa-toilet:before {
	content: "\f7d8";
}

.fa-toilet-paper:before {
	content: "\f71e";
}

.fa-toilet-paper-slash:before {
	content: "\e072";
}

.fa-toolbox:before {
	content: "\f552";
}

.fa-tools:before {
	content: "\f7d9";
}

.fa-tooth:before {
	content: "\f5c9";
}

.fa-torah:before {
	content: "\f6a0";
}

.fa-torii-gate:before {
	content: "\f6a1";
}

.fa-tractor:before {
	content: "\f722";
}

.fa-trade-federation:before {
	content: "\f513";
}

.fa-trademark:before {
	content: "\f25c";
}

.fa-traffic-light:before {
	content: "\f637";
}

.fa-trailer:before {
	content: "\e041";
}

.fa-train:before {
	content: "\f238";
}

.fa-tram:before {
	content: "\f7da";
}

.fa-transgender:before {
	content: "\f224";
}

.fa-transgender-alt:before {
	content: "\f225";
}

.fa-trash:before {
	content: "\f1f8";
}

.fa-trash-alt:before {
	content: "\f2ed";
}

.fa-trash-restore:before {
	content: "\f829";
}

.fa-trash-restore-alt:before {
	content: "\f82a";
}

.fa-tree:before {
	content: "\f1bb";
}

.fa-trello:before {
	content: "\f181";
}

.fa-tripadvisor:before {
	content: "\f262";
}

.fa-trophy:before {
	content: "\f091";
}

.fa-truck:before {
	content: "\f0d1";
}

.fa-truck-loading:before {
	content: "\f4de";
}

.fa-truck-monster:before {
	content: "\f63b";
}

.fa-truck-moving:before {
	content: "\f4df";
}

.fa-truck-pickup:before {
	content: "\f63c";
}

.fa-tshirt:before {
	content: "\f553";
}

.fa-tty:before {
	content: "\f1e4";
}

.fa-tumblr:before {
	content: "\f173";
}

.fa-tumblr-square:before {
	content: "\f174";
}

.fa-tv:before {
	content: "\f26c";
}

.fa-twitch:before {
	content: "\f1e8";
}

.fa-twitter:before {
	content: "\f099";
}

.fa-twitter-square:before {
	content: "\f081";
}

.fa-typo3:before {
	content: "\f42b";
}

.fa-uber:before {
	content: "\f402";
}

.fa-ubuntu:before {
	content: "\f7df";
}

.fa-uikit:before {
	content: "\f403";
}

.fa-umbraco:before {
	content: "\f8e8";
}

.fa-umbrella:before {
	content: "\f0e9";
}

.fa-umbrella-beach:before {
	content: "\f5ca";
}

.fa-uncharted:before {
	content: "\e084";
}

.fa-underline:before {
	content: "\f0cd";
}

.fa-undo:before {
	content: "\f0e2";
}

.fa-undo-alt:before {
	content: "\f2ea";
}

.fa-uniregistry:before {
	content: "\f404";
}

.fa-unity:before {
	content: "\e049";
}

.fa-universal-access:before {
	content: "\f29a";
}

.fa-university:before {
	content: "\f19c";
}

.fa-unlink:before {
	content: "\f127";
}

.fa-unlock:before {
	content: "\f09c";
}

.fa-unlock-alt:before {
	content: "\f13e";
}

.fa-unsplash:before {
	content: "\e07c";
}

.fa-untappd:before {
	content: "\f405";
}

.fa-upload:before {
	content: "\f093";
}

.fa-ups:before {
	content: "\f7e0";
}

.fa-usb:before {
	content: "\f287";
}

.fa-user:before {
	content: "\f007";
}

.fa-user-alt:before {
	content: "\f406";
}

.fa-user-alt-slash:before {
	content: "\f4fa";
}

.fa-user-astronaut:before {
	content: "\f4fb";
}

.fa-user-check:before {
	content: "\f4fc";
}

.fa-user-circle:before {
	content: "\f2bd";
}

.fa-user-clock:before {
	content: "\f4fd";
}

.fa-user-cog:before {
	content: "\f4fe";
}

.fa-user-edit:before {
	content: "\f4ff";
}

.fa-user-friends:before {
	content: "\f500";
}

.fa-user-graduate:before {
	content: "\f501";
}

.fa-user-injured:before {
	content: "\f728";
}

.fa-user-lock:before {
	content: "\f502";
}

.fa-user-md:before {
	content: "\f0f0";
}

.fa-user-minus:before {
	content: "\f503";
}

.fa-user-ninja:before {
	content: "\f504";
}

.fa-user-nurse:before {
	content: "\f82f";
}

.fa-user-plus:before {
	content: "\f234";
}

.fa-user-secret:before {
	content: "\f21b";
}

.fa-user-shield:before {
	content: "\f505";
}

.fa-user-slash:before {
	content: "\f506";
}

.fa-user-tag:before {
	content: "\f507";
}

.fa-user-tie:before {
	content: "\f508";
}

.fa-user-times:before {
	content: "\f235";
}

.fa-users:before {
	content: "\f0c0";
}

.fa-users-cog:before {
	content: "\f509";
}

.fa-users-slash:before {
	content: "\e073";
}

.fa-usps:before {
	content: "\f7e1";
}

.fa-ussunnah:before {
	content: "\f407";
}

.fa-utensil-spoon:before {
	content: "\f2e5";
}

.fa-utensils:before {
	content: "\f2e7";
}

.fa-vaadin:before {
	content: "\f408";
}

.fa-vector-square:before {
	content: "\f5cb";
}

.fa-venus:before {
	content: "\f221";
}

.fa-venus-double:before {
	content: "\f226";
}

.fa-venus-mars:before {
	content: "\f228";
}

.fa-vest:before {
	content: "\e085";
}

.fa-vest-patches:before {
	content: "\e086";
}

.fa-viacoin:before {
	content: "\f237";
}

.fa-viadeo:before {
	content: "\f2a9";
}

.fa-viadeo-square:before {
	content: "\f2aa";
}

.fa-vial:before {
	content: "\f492";
}

.fa-vials:before {
	content: "\f493";
}

.fa-viber:before {
	content: "\f409";
}

.fa-video:before {
	content: "\f03d";
}

.fa-video-slash:before {
	content: "\f4e2";
}

.fa-vihara:before {
	content: "\f6a7";
}

.fa-vimeo:before {
	content: "\f40a";
}

.fa-vimeo-square:before {
	content: "\f194";
}

.fa-vimeo-v:before {
	content: "\f27d";
}

.fa-vine:before {
	content: "\f1ca";
}

.fa-virus:before {
	content: "\e074";
}

.fa-virus-slash:before {
	content: "\e075";
}

.fa-viruses:before {
	content: "\e076";
}

.fa-vk:before {
	content: "\f189";
}

.fa-vnv:before {
	content: "\f40b";
}

.fa-voicemail:before {
	content: "\f897";
}

.fa-volleyball-ball:before {
	content: "\f45f";
}

.fa-volume-down:before {
	content: "\f027";
}

.fa-volume-mute:before {
	content: "\f6a9";
}

.fa-volume-off:before {
	content: "\f026";
}

.fa-volume-up:before {
	content: "\f028";
}

.fa-vote-yea:before {
	content: "\f772";
}

.fa-vr-cardboard:before {
	content: "\f729";
}

.fa-vuejs:before {
	content: "\f41f";
}

.fa-walking:before {
	content: "\f554";
}

.fa-wallet:before {
	content: "\f555";
}

.fa-warehouse:before {
	content: "\f494";
}

.fa-watchman-monitoring:before {
	content: "\e087";
}

.fa-water:before {
	content: "\f773";
}

.fa-wave-square:before {
	content: "\f83e";
}

.fa-waze:before {
	content: "\f83f";
}

.fa-weebly:before {
	content: "\f5cc";
}

.fa-weibo:before {
	content: "\f18a";
}

.fa-weight:before {
	content: "\f496";
}

.fa-weight-hanging:before {
	content: "\f5cd";
}

.fa-weixin:before {
	content: "\f1d7";
}

.fa-whatsapp:before {
	content: "\f232";
}

.fa-whatsapp-square:before {
	content: "\f40c";
}

.fa-wheelchair:before {
	content: "\f193";
}

.fa-whmcs:before {
	content: "\f40d";
}

.fa-wifi:before {
	content: "\f1eb";
}

.fa-wikipedia-w:before {
	content: "\f266";
}

.fa-wind:before {
	content: "\f72e";
}

.fa-window-close:before {
	content: "\f410";
}

.fa-window-maximize:before {
	content: "\f2d0";
}

.fa-window-minimize:before {
	content: "\f2d1";
}

.fa-window-restore:before {
	content: "\f2d2";
}

.fa-windows:before {
	content: "\f17a";
}

.fa-wine-bottle:before {
	content: "\f72f";
}

.fa-wine-glass:before {
	content: "\f4e3";
}

.fa-wine-glass-alt:before {
	content: "\f5ce";
}

.fa-wix:before {
	content: "\f5cf";
}

.fa-wizards-of-the-coast:before {
	content: "\f730";
}

.fa-wodu:before {
	content: "\e088";
}

.fa-wolf-pack-battalion:before {
	content: "\f514";
}

.fa-won-sign:before {
	content: "\f159";
}

.fa-wordpress:before {
	content: "\f19a";
}

.fa-wordpress-simple:before {
	content: "\f411";
}

.fa-wpbeginner:before {
	content: "\f297";
}

.fa-wpexplorer:before {
	content: "\f2de";
}

.fa-wpforms:before {
	content: "\f298";
}

.fa-wpressr:before {
	content: "\f3e4";
}

.fa-wrench:before {
	content: "\f0ad";
}

.fa-x-ray:before {
	content: "\f497";
}

.fa-xbox:before {
	content: "\f412";
}

.fa-xing:before {
	content: "\f168";
}

.fa-xing-square:before {
	content: "\f169";
}

.fa-y-combinator:before {
	content: "\f23b";
}

.fa-yahoo:before {
	content: "\f19e";
}

.fa-yammer:before {
	content: "\f840";
}

.fa-yandex:before {
	content: "\f413";
}

.fa-yandex-international:before {
	content: "\f414";
}

.fa-yarn:before {
	content: "\f7e3";
}

.fa-yelp:before {
	content: "\f1e9";
}

.fa-yen-sign:before {
	content: "\f157";
}

.fa-yin-yang:before {
	content: "\f6ad";
}

.fa-yoast:before {
	content: "\f2b1";
}

.fa-youtube:before {
	content: "\f167";
}

.fa-youtube-square:before {
	content: "\f431";
}

.fa-zhihu:before {
	content: "\f63f";
}

@font-face {
	font-display: block;
	font-family: "Font Awesome 5 Brands";
	font-style: normal;
	font-weight: 400;
	src: url("../fonts/fa-brands-400.eot");
	src: url("../fonts/fa-brands-400.eot?#iefix") format("embedded-opentype"),
		url("../fonts/fa-brands-400.woff2") format("woff2"),
		url("../fonts/fa-brands-400.woff") format("woff"),
		url("../fonts/fa-brands-400.ttf") format("truetype"),
		url("../fonts/fa-brands-400.svg#fontawesome") format("svg");
}

.fab {
	font-family: "Font Awesome 5 Brands";
	font-weight: 400;
}

@font-face {
	font-display: block;
	font-family: "Font Awesome 5 Free";
	font-style: normal;
	font-weight: 900;
	src: url("../fonts/fa-solid-900.eot");
	src: url("../fonts/fa-solid-900.eot?#iefix") format("embedded-opentype"),
		url("../fonts/fa-solid-900.woff2") format("woff2"),
		url("../fonts/fa-solid-900.woff") format("woff"),
		url("../fonts/fa-solid-900.ttf") format("truetype"),
		url("../fonts/fa-solid-900.svg#fontawesome") format("svg");
}

.fa,
.fas {
	font-family: "Font Awesome 5 Free";
	font-weight: 900;
}


.uk-button .fa-arrow-circle-right {
	font-size: 13px;
	display: inline-block;
	transform: rotate(-40deg);
	transition: all linear 100ms;
}

.uk-button:hover .fa-arrow-circle-right {
	transform: rotate(0deg);
}

.uk-button-text {
	color: #4886d9;
}

.uk-button-text:hover {
	color: #296cc5;
}

.in-label-small {
	font-size: 13px;
	padding: 2px 7px 1px;
}

.in-equity-breadcrumb {
	background: #3772ff;
	box-shadow: 0 2px 8px rgba(0, 0, 0, 0.08);
	margin-bottom: 20px;
}

.in-equity-breadcrumb .uk-breadcrumb {
	padding-top: 13px;
	padding-bottom: 16px;
}

.in-equity-1 .uk-card {
	min-height: 252px;
	font-size: 16px;
	box-shadow: 0px 4px 25px -2px rgba(0, 0, 0, 0.12);
}

.in-equity-1 .uk-card .uk-button-text::before {
	border-color: #4886d9;
}

.in-equity-1 .uk-card .uk-button-text.uk-position-bottom-right {
	right: 34px;
	bottom: 34px;
}

.in-equity-1 .uk-card .in-product-name {
	width: 24px;
	height: 24px;
	color: #95a5a6;
	background-color: #fff;
	border-radius: 50%;
	font-size: 9px;
	font-weight: 700;
	text-align: center;
	line-height: 24px;
	margin-right: 8px;
}

.in-equity-1 .uk-card .in-product-name i {
	font-size: 12px;
	line-height: 25px;
}

.in-equity-1 .uk-card .in-product-name.red {
	color: #fff;
	background-color: #e54a41;
}

.in-equity-1 .uk-card .in-product-name.green {
	color: #fff;
	background-color: #37bc9c;
}

.in-equity-1 .uk-card .in-product-name.blue {
	color: #fff;
	background-color: #4886d9;
}

.in-equity-1 .uk-card .in-product-name.yellow {
	color: #fff;
	background-color: #ffa702;
}

.in-equity-1 .uk-card-body {
	padding: 30px 34px 58px;
}

.in-equity-1 .uk-card-default {
	background: #fff;
}

.in-equity-2 .in-feature-box a {
	color: #707070;
	transition: all ease 600ms;
}

.in-equity-2 .in-feature-box a .in-icon-wrap {
	width: 80px;
	height: 80px;
	background-color: #fff;
	border-radius: 10px;
	box-shadow: 0px 6px 20px -2px rgba(70, 76, 81, 0.1);
	transition: all ease 600ms;
}

.in-equity-2 .in-feature-box a .in-icon-wrap img {
	height: 42px;
}

.in-equity-2 .in-feature-box a:hover {
	color: #0d0c43;
	text-decoration: none;
}

.in-equity-2 .in-feature-box a:hover .in-icon-wrap {
	box-shadow: 0px 0px 35px -2px rgba(252, 180, 45, 0.5);
}

@media (max-width: 960px) {
	.in-equity-2.uk-background-contain {
		background-size: 640px 140px;
		background-position: 0% 36%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-2.uk-background-contain {
		background-size: 1250px 179px;
	}
}

.in-equity-3 .uk-text-warning {
	color: #0d0c43 !important;
}

.in-equity-3 .uk-card {
	width: 590px;
	margin-right: 25px;
	position: relative;
}

.in-equity-3 .uk-card:after {
	background: #0d0c43;
	content: "";
	width: 590px;
	height: 400px;
	position: absolute;
	z-index: -1;
	top: 0px;
	left: 0px;
	transform: rotate(-8deg);
	border-radius: 10px;
}

.in-equity-3 .uk-card-body {
	padding: 20px 10px;
}

.in-equity-3 .widget-card {
	padding: 0 22px 22px 24px;
}

.in-equity-3 .uk-card-default {
	background-color: #fff;
	box-shadow: 0px 6px 20px -2px rgba(70, 76, 81, 0.2);
}

@media (max-width: 960px) {
	.in-equity-3 .uk-card {
		margin-right: 0;
	}

	.in-equity-3 .uk-card:after {
		width: 100%;
	}
}

.in-equity-4 {
	background-color: #fff;
	border-top: 1px solid #e9eaec;
	border-bottom: 1px solid #e9eaec;
}

.in-equity-4 .in-testimonial-2 .uk-background-contain {
	padding-top: 25px;
	background-size: 231px 250px;
}

.in-equity-4 .in-testimonial-2 blockquote {
	font-size: 24px;
	font-family: "Archivo", sans-serif;
	color: #2a2a2a;
	margin-top: 2px;
	padding: 0 0 21px 57px;
}

.in-equity-4 .in-testimonial-2 blockquote p:first-of-type::before {
	content: "“";
	font-family: "Archivo", sans-serif;
	font-size: 172px;
	font-style: italic;
	color: #2a2a2a;
	position: absolute;
	margin: -122px 0 0 -29px;
}

.in-equity-5 {
	background-color: #fff;
}

.in-equity-5 .in-award h6 {
	
	margin: 5px 0 0px;
}

.in-equity-5 .in-award .provider {
	color: #212529;
	font-size: 16px;
	margin: 7px 0 -12px;
}

.in-equity-5 .in-award .year {
	color: #dddddd;
	font-size: 30px;
	margin-bottom: 0px;
}

.in-equity-5 .in-award img {
	
}

.in-equity-6.uk-background-contain {
	background-size: 765px 432px;
	background-position: 65% 5%;
}

.in-equity-6 .uk-text-lead {
	color: #fff;
}

.in-equity-6 .uk-button-secondary {
	color: #252526;
	background-color: #fff;
}

@media (max-width: 960px) {
	.in-equity-6.uk-background-contain {
		background-size: 765px 432px;
		background-position: 15% 100%;
	}

	.in-equity-6 .uk-flex.button-app {
		display: block;
		text-align: center;
	}

	.in-equity-6 .uk-flex.button-app div {
		margin-bottom: 20px;
	}

	.in-equity-6 .uk-flex.button-app .uk-margin-right {
		margin-right: 0 !important;
	}

	.in-equity-6 .uk-flex.button-app .uk-margin-left {
		margin-left: 0 !important;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-6.uk-background-contain {
		background-position: 140px 100%;
	}
}

.in-equity-7 .uk-card-default {
	background-color: rgba(255, 255, 255, 0.65);
}

.in-equity-7 .uk-card-body {
	padding: 30px;
}

.in-equity-7 .in-symbol-1 {
	width: 270px;
	height: 270px;
	-webkit-animation: float 6s ease-in-out infinite;
	animation: float 6s ease-in-out infinite;
}

.in-equity-7 .in-symbol-2 {
	width: 205px;
	height: 205px;
	-webkit-animation: float 6s ease-in-out infinite;
	animation: float 6s ease-in-out infinite;
}

.in-equity-7 .in-symbol-3 {
	width: 140px;
	height: 140px;
	-webkit-animation: float 6s ease-in-out infinite;
	animation: float 6s ease-in-out infinite;
}

.in-equity-7 .in-symbol-4 {
	width: 105px;
	height: 105px;
	-webkit-animation: float 6s ease-in-out infinite;
	animation: float 6s ease-in-out infinite;
}

.in-equity-7 .in-symbol-5 {
	width: 65px;
	height: 65px;
	background: #1bb0ed;
	border-radius: 50%;
}

.in-equity-7 .in-symbol-6 {
	width: 55px;
	height: 55px;
	background: #59b84e;
	border-radius: 50%;
}

.in-equity-7 .in-symbol-7 {
	width: 70px;
	height: 70px;
	background: #fac82b;
	border-radius: 50%;
}

.in-equity-7 .in-symbol-8 {
	width: 35px;
	height: 35px;
	background: #3985fc;
	border-radius: 50%;
}

@keyframes float {
	0% {
		transform: translatey(0px);
	}

	50% {
		transform: translatey(-10px);
	}

	100% {
		transform: translatey(0px);
	}
}

@media (max-width: 960px) {
	.in-equity-7.uk-background-contain {
		background-size: 1200px 376px;
		background-position: 35% 0%;
	}

	.in-equity-7 .in-symbol-wrap {
		padding-left: 12%;
		height: 380px;
	}

	.in-equity-7 .in-symbol-1 {
		width: 135px;
		height: 135px;
		left: 20% !important;
		top: 42% !important;
	}

	.in-equity-7 .in-symbol-2 {
		width: 102px;
		height: 102px;
	}

	.in-equity-7 .in-symbol-3 {
		width: 70px;
		height: 70px;
	}

	.in-equity-7 .in-symbol-4 {
		width: 52px;
		height: 52px;
	}

	.in-equity-7 .in-symbol-5 {
		width: 45px;
		height: 45px;
	}

	.in-equity-7 .in-symbol-6 {
		width: 35px;
		height: 35px;
	}

	.in-equity-7 .in-symbol-7 {
		width: 50px;
		height: 50px;
		left: 60% !important;
		top: 84% !important;
	}

	.in-equity-7 .in-symbol-8 {
		width: 15px;
		height: 15px;
		left: 32% !important;
		top: 87% !important;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-7 .in-symbol-1 {
		width: 165px;
		height: 165px;
		top: 32% !important;
		left: 23% !important;
	}

	.in-equity-7 .in-symbol-2 {
		width: 122px;
		height: 122px;
		left: 54% !important;
	}

	.in-equity-7 .in-symbol-3 {
		width: 90px;
		height: 90px;
		top: 0% !important;
	}

	.in-equity-7 .in-symbol-4 {
		width: 52px;
		height: 52px;
	}

	.in-equity-7 .in-symbol-5 {
		width: 45px;
		height: 45px;
	}

	.in-equity-7 .in-symbol-6 {
		width: 35px;
		height: 35px;
	}

	.in-equity-7 .in-symbol-7 {
		width: 50px;
		height: 50px;
	}

	.in-equity-7 .in-symbol-8 {
		width: 15px;
		height: 15px;
	}
}

.in-equity-8 {
	background: #040c43;
	background: linear-gradient(0deg, #040c43 0%, #040c43 90%, #040c43 100%);
}

.in-equity-8 .in-current-stats .uk-text-small {
	font-size: 12px;
}

.in-equity-8 .in-current-stats h2.uk-text-primary {
	font-size: 36px;
	border: 1px solid #fff;
	border-radius: 10px;
	padding: 10px 18px;
}

.in-equity-8 .uk-card-secondary {
	height: 407px;
	background-color: rgba(0, 0, 0, 0.25);
}

.in-equity-8 .uk-card-body {
	padding: 20px 10px;
}

.in-equity-8 .widget-card {
	padding: 0 22px 22px 24px;
}

.in-equity-9 .uk-background-contain {
	background-size: 310px 410px;
}

.in-equity-9 .in-register {
	position: relative;
}

.in-equity-9 .in-register .in-icon-wrap {
	width: 56px;
	height: 56px;
	background-color: #f5f7f9;
	box-shadow: inset 0px 0px 0px 2px #0d0c43;
	border: 18px solid #f5f7f9;
	font-size: 22px;
	font-family: "Archivo", sans-serif;
	color: #0d0c43;
	margin: -20px 0 -25px;
	position: relative;
	z-index: 0.1;
}

.in-equity-9 .in-register .in-h-line::after {
	width: 61%;
	height: 1px;
	background-color: #d8dfe2;
	position: absolute;
	content: "";
	top: 40%;
	left: 22%;
	z-index: 0;
}

.in-equity-9 .uk-card-primary h4,
.in-equity-9 .uk-card-primary i {
	color: #333333;
}

.in-equity-9 .uk-card-primary p {
	color: #fff;
}

.in-equity-9 .uk-card-primary .uk-button-text::before {
	border-color: #4886d9;
}

.in-equity-9 .uk-card-primary.uk-card-body .uk-button-text {
	color: #333333;
}

@media (max-width: 960px) {
	.in-equity-9 .uk-background-contain {
		background-position: 420% 0%;
	}

	.in-equity-9 .in-register .in-h-line::after {
		display: none;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-9 .uk-background-contain {
		background-position: 110% 0%;
	}

	.in-equity-9 .in-register .in-h-line::after {
		display: block;
		top: 34%;
	}
}

.in-equity-10 .uk-card-body {
	padding-top: 50px;
	padding-bottom: 50px;
}

.in-equity-10 .in-client-logo-3 .uk-tile {
	background: #fff;
}

@media (max-width: 960px) {
	.in-equity-10 .uk-flex {
		display: block;
		text-align: center;
	}

	.in-equity-10 .in-client-logo-3 .uk-tile img {
		position: relative;
		left: 5%;
	}
}

.in-equity-11.uk-background-contain {
	background-size: 832px 480px;
	background-position: 85% 0%;
}

.in-equity-11 .uk-card-default {
	background-color: rgba(255, 255, 255, 0.75);
}

.in-equity-11 .uk-card-body {
	padding: 26px;
}

@media (max-width: 960px) {
	.in-equity-11.uk-background-contain {
		background-size: 640px 369px;
		background-position: -50% 0%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-11.uk-background-contain {
		background-position: 250% 0%;
	}
}

.in-equity-12 .uk-card-body {
	padding: 50px 50px 60px;
}

.in-equity-12 .in-img-mockup {
	position: relative;
	bottom: -60px;
}

.in-equity-12
	.uk-card-secondary
	> :not([class*="uk-card-media"])
	.uk-button-primary {
	color: #252526;
	background-color: #0d0c43;
}

.in-equity-12 .in-icon-wrap {
	color: #fff;
	background: #57575a;
	font-size: 22px;
	font-weight: 700;
	width: 54px;
	height: 54px;
	transition: all ease 600ms;
}

.in-equity-12 .in-steps {
	border: 1px solid #57575a;
	border-radius: 10px;
	padding: 20px 0 0 20px;
	transition: all ease 600ms;
}

.in-equity-12 .in-steps.active-step {
	border-color: #0d0c43;
	cursor: pointer;
}

.in-equity-12 .in-steps.active-step .in-icon-wrap {
	color: #252526;
	background: #0d0c43;
	transition: all ease 600ms;
}

@media (max-width: 960px) {
	.in-equity-12 .button-app.uk-flex {
		display: block;
		text-align: center;
	}

	.in-equity-12 .button-app.uk-flex .uk-button {
		margin-top: 20px;
		margin-left: 0 !important;
	}

	.in-equity-12 .uk-card-body {
		padding: 30px 30px 10px;
	}

	.in-equity-12 .in-img-mockup {
		bottom: -10px;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-12 h2 {
		text-align: center;
	}

	.in-equity-12 .button-app.uk-flex {
		margin-top: 30px;
	}

	.in-equity-12 .button-app.uk-flex .uk-button {
		margin-top: 0px;
		margin-left: 25px !important;
	}
}

.in-equity-13 div article {
	border-bottom: 1px solid #e8e8e8;
	padding-top: 18px;
	padding-bottom: 20px;
}

.in-equity-13 div article h5 {
	margin-bottom: 5px;
}

.in-equity-13 div article h5 a {
	color: #333333;
}

.in-equity-13 div article .uk-text-small {
	font-size: 12px;
}

.in-equity-13 div article:last-child {
	border-bottom: 0;
}

.in-equity-13 .uk-card-default {
	background: transparent;
	border: 1px solid #c7daf3;
	box-shadow: 0 2px 8px rgba(34, 89, 163, 0.1);
}

.in-equity-13 .uk-card-body {
	padding: 20px;
}

.in-equity-13 .uk-subnav li a {
	color: #4886d9;
}

.in-equity-13 .uk-subnav li .in-icon-wrap {
	color: #4886d9;
	background-color: #dce8f8;
}

.in-equity-13
	.uk-subnav-divider
	> :nth-child(n + 2):not(.uk-first-column)::before {
	border-color: #c7daf3;
}

.in-equity-14.uk-background-contain {
	background-size: 780px 390px;
	background-position: 35% 5%;
}

.in-equity-14 .in-award-logo {
	position: relative;
	z-index: 1;
}

.in-equity-14 .in-award-badge {
	background: rgba(255, 255, 255, 0.3);
	backdrop-filter: blur(4px);
	-webkit-backdrop-filter: blur(4px);
	border: 1px solid rgba(255, 255, 255, 0.5);
	border-radius: 18px;
	padding: 11px 25px 15px 80px;
	position: relative;
	left: -85px;
}

.in-equity-14 .in-award-badge .uk-text-small {
	color: #4886d9;
}

.in-equity-14 .in-heading-thin {
	font-weight: 300;
}

.in-equity-14 .in-list-check li {
	color: #333333;
	font-weight: 700;
}

.in-equity-14 .in-list-check > li::before {
	font-size: 23px;
	color: #4886d9;
	z-index: 1;
	position: relative;
	top: -6px;
	left: -18px;
}

.in-equity-14 .in-list-check > li::after {
	width: 21px;
	height: 21px;
	background: #fff;
	content: "";
	float: left;
	border-radius: 50%;
	position: relative;
	left: -10px;
	z-index: 0;
}

@media (max-width: 960px) {
	.in-equity-14 .in-award-badge {
		width: 100%;
		padding: 11px 0px 4px 48px;
		left: -55px;
		border-top-left-radius: 0;
		border-bottom-left-radius: 0;
	}

	.in-equity-14 .in-award-badge h3 {
		font-size: 1.2rem;
	}

	.in-equity-14 .in-award-badge h4 {
		font-size: 0.95rem;
	}

	.in-equity-14 .uk-flex.right-content {
		display: block;
	}

	.in-equity-14 .uk-flex.right-content .in-list-check {
		margin-left: -20px;
	}

	.in-equity-14 .uk-flex.right-content .uk-margin-large-left {
		margin-left: 0 !important;
	}

	.in-equity-14 .uk-flex.right-content .uk-button {
		margin-top: 30px;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-14 .in-award-logo {
		margin-left: 22%;
	}

	.in-equity-14 .in-award-badge {
		width: 32%;
		padding: 15px 0px 8px 48px;
	}

	.in-equity-14 .in-award-badge h3 {
		font-size: 1.4rem;
	}

	.in-equity-14 .in-award-badge h4 {
		font-size: 1.1rem;
	}

	.in-equity-14 .uk-flex.right-content {
		margin-left: 35%;
	}

	.in-equity-14 .uk-flex.right-content .uk-margin-large-left {
		margin-left: -20px !important;
	}
}

.in-equity-15.uk-background-contain {
	background-position: 68% 0%;
}

.in-equity-15 .uk-text-lead {
	color: rgba(255, 255, 255, 0.7);
}

.in-equity-15 .uk-button-primary {
	color: #252526;
	background: #fff;
}

.in-equity-15 .uk-button-default {
	color: #3e3e40;
	box-shadow: inset 0px 0px 0px 1px #57575a;
}

.in-equity-15 hr {
	margin: 50px 0 40px;
	border-color: rgba(0, 0, 0, 0.18);
}

@media (max-width: 960px) {
	.in-equity-15.uk-background-contain {
		background-size: 560px 428px;
	}

	.in-equity-15.uk-background-center {
		background-position: -10% 0% !important;
	}

	.in-equity-15 .uk-flex.get-started {
		display: block;
		text-align: center;
	}

	.in-equity-15 .uk-flex.get-started .uk-margin-left {
		margin-top: 20px;
		margin-left: 0 !important;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-15.uk-background-contain {
		background-size: 760px 581px;
	}

	.in-equity-15.uk-background-center {
		background-position: 300px 0% !important;
	}

	.in-equity-15 .uk-flex.get-started .uk-margin-left {
		margin-top: 26px;
		margin-left: 10px !important;
	}
}

.in-equity-16 {
	background-color: #fff;
}

.in-equity-16 .uk-card-default {
	background-color: transparent;
	border-radius: 10px;
	border: 1px solid #d8d8d8;
	cursor: default;
	padding: 15px;
	transition: all ease 600ms;
}

.in-equity-16 .uk-card-default i {
	color: #0d0c43;
	font-size: 38px;
	background: #fff;
	border-left: 25px solid #fff;
	border-right: 25px solid #fff;
	position: relative;
	top: -34px;
}

.in-equity-16 .uk-card-default h5 {
	margin-top: -22px;
	margin-bottom: -13px;
}

.in-equity-16 .uk-card-default p {
	padding-bottom: 8px;
}

.in-equity-16 .uk-card-default:hover {
	cursor: pointer;
	border-color: #0d0c43;
	text-decoration: none;
	box-shadow: 0 5px 15px rgba(0, 0, 0, 0.08);
}

.in-equity-video {
	width: 97%;
	margin-right: 25px;
	position: relative;
}

.in-equity-video:hover img {
	transition: all ease 600ms;
	filter: brightness(100%);
}

.in-equity-video img,
.in-equity-video .uk-position-center {
	position: relative;
	z-index: 1;
}

.in-equity-video img {
	filter: brightness(60%);
	box-shadow: 0px 6px 20px -2px rgba(70, 76, 81, 0.2);
	transition: all ease 600ms;
}

.in-equity-video .in-play-button {
	width: 75px;
	height: 75px;
	border-radius: 50px;
	background: rgba(255, 255, 255, 0.9);
	box-shadow: 0 0 0 0 white;
	-webkit-animation: pulse-white 2s infinite;
	animation: pulse-white 2s infinite;
	z-index: 1;
}

.in-equity-video i {
	color: #0d0c43;
	font-size: 24px;
	position: absolute;
	top: 25px;
	left: 28px;
}

.in-equity-video:before {
	content: "";
	width: 100%;
	height: 100%;
	position: absolute;
	top: 0px;
	left: 0px;
	transform: rotate(-8deg);
	border-radius: 10px;
}

@-webkit-keyframes pulse-white {
	0% {
		box-shadow: 0 0 0 0 rgba(255, 255, 255, 0.7);
	}

	70% {
		box-shadow: 0 0 0 40px rgba(255, 255, 255, 0);
	}

	100% {
		box-shadow: 0 0 0 0 rgba(255, 255, 255, 0);
	}
}

@keyframes pulse-white {
	0% {
		box-shadow: 0 0 0 0 rgba(255, 255, 255, 0.7);
	}

	70% {
		box-shadow: 0 0 0 40px rgba(255, 255, 255, 0);
	}

	100% {
		box-shadow: 0 0 0 0 rgba(255, 255, 255, 0);
	}
}

.in-equity-17 .uk-card-default {
	background-color: #fff;
	border-radius: 10px;
	border: 1px solid #d8d8d8;
}

.in-equity-17 .uk-card-body {
	padding-left: 45px;
	padding-right: 45px;
}

.in-equity-17 .in-equity-pricing div:first-child .uk-card {
	border-right: 0;
	border-top-right-radius: 0;
	border-bottom-right-radius: 0;
	margin-top: 35px;
}

.in-equity-17 .in-equity-pricing div:last-child .uk-card-body {
	padding-top: 75px;
	padding-bottom: 75px;
}

.in-equity-17 .in-equity-pricing div:last-child .uk-card-default {
	border-color: #0d0c43;
}

@media (max-width: 960px) {
	.in-equity-17 .in-equity-pricing div:first-child .uk-card {
		border-right: 2px solid #e8e8e8;
		border-top-right-radius: 10px;
		border-bottom-right-radius: 10px;
		margin-top: 0;
		margin-bottom: 35px;
	}

	.in-equity-17 .in-equity-pricing div:last-child .uk-card-body {
		padding-top: 30px;
		padding-bottom: 30px;
	}
}

.in-equity-18 .in-client-logo-6 .uk-tile {
	background: #fff;
}

@media (max-width: 960px) {
	.in-equity-18 .in-client-logo-6 img {
		width: 35%;
	}
}

@media (min-width: 640px) and (max-width: 960px) {
	.in-equity-18 .in-client-logo-6 .uk-tile:nth-child(5) {
		border-bottom: 0;
	}
}

@-webkit-keyframes spinner-border {
	to {
		transform: rotate(360deg);
	}
}

@keyframes spinner-border {
	to {
		transform: rotate(360deg);
	}
}

.spinner-border {
	display: inline-block;
	width: 2rem;
	height: 2rem;
	vertical-align: text-bottom;
	border: 0.25em solid currentColor;
	border-right-color: transparent;
	border-radius: 50%;
	-webkit-animation: spinner-border 0.75s linear infinite;
	animation: spinner-border 0.75s linear infinite;
}

.spinner-border-sm {
	width: 1rem;
	height: 1rem;
	border-width: 0.2em;
}

@-webkit-keyframes spinner-grow {
	0% {
		transform: scale(0);
	}

	50% {
		opacity: 1;
		transform: none;
	}
}

@keyframes spinner-grow {
	0% {
		transform: scale(0);
	}

	50% {
		opacity: 1;
		transform: none;
	}
}

.spinner-grow {
	display: inline-block;
	width: 2rem;
	height: 2rem;
	vertical-align: text-bottom;
	background-color: currentColor;
	border-radius: 50%;
	opacity: 0;
	-webkit-animation: spinner-grow 0.75s linear infinite;
	animation: spinner-grow 0.75s linear infinite;
}

.spinner-grow-sm {
	width: 1rem;
	height: 1rem;
}


.white {
	color: #fff !important;
}

.blue {
	color: #3772ff !important;
}

.grey {
	color: #212529 !important;
}

.d-block {
	display: block;
}

.nav-ico {
	transform: rotate(0deg);
	width: 40px !important;
	height: 40px !important;
	fill: rgb(255, 255, 255);
	color: rgb(255, 255, 255);
	margin-right: 16px;
}

.table .thead-light th {
	color: #666c73;
	background-color: #fff;
	border-color: #dee2e6;
	z-index: 1;
	transition-duration: 0.6s;
	font-size: 1.02rem;
	font-weight: 400;
	line-height: 1.5;
}

.table thead th {
	vertical-align: bottom;
	border-bottom: 1px solid #dee2e6;
	padding: 0.75rem;
	border-top: none !important;
}

.table tbody td {
	color: #212529;
	transition-duration: 0.6s;
	font-size: 1.1rem;
	font-weight: 500;
	line-height: 1.5;
	background-color: #fff;
	border: none !important;
	padding-top: 25px;
	padding-bottom: 25px;
}

.pricing-checked {
	width: 25px;
	height: 25px;
	background: #3772ff;
	border-radius: 100px;
	color: #fff;
	font-size: 14px;
	text-align: center;
	margin: 0px !important;
}

.pricing-checked i {
	text-align: center;
	vertical-align: text-bottom;
}

.pricing-unchecked {
	width: 25px;
	height: 25px;
	background: red;
	border-radius: 100px;
	color: #fff;
	font-size: 14px;
	text-align: center;
	margin: 0px !important;
}

.pricing-unchecked i {
	text-align: center;
	vertical-align: text-bottom;
}

.cus-select {
	width: 50% !important;
}
.pricing-des{
    text-align:center;
}
